(function () {
/**
 * almond 0.2.0 Copyright (c) 2011, The Dojo Foundation All Rights Reserved.
 * Available via the MIT or new BSD license.
 * see: http://github.com/jrburke/almond for details
 */
//Going sloppy to avoid 'use strict' string cost, but strict practices should
//be followed.
/*jslint sloppy: true */
/*global setTimeout: false */

var requirejs, require, define;
(function (undef) {
    var main, req, makeMap, handlers,
        defined = {},
        waiting = {},
        config = {},
        defining = {},
        aps = [].slice;

    /**
     * Given a relative module name, like ./something, normalize it to
     * a real name that can be mapped to a path.
     * @param {String} name the relative name
     * @param {String} baseName a real name that the name arg is relative
     * to.
     * @returns {String} normalized name
     */
    function normalize(name, baseName) {
        var nameParts, nameSegment, mapValue, foundMap,
            foundI, foundStarMap, starI, i, j, part,
            baseParts = baseName && baseName.split("/"),
            map = config.map,
            starMap = (map && map['*']) || {};

        //Adjust any relative paths.
        if (name && name.charAt(0) === ".") {
            //If have a base name, try to normalize against it,
            //otherwise, assume it is a top-level require that will
            //be relative to baseUrl in the end.
            if (baseName) {
                //Convert baseName to array, and lop off the last part,
                //so that . matches that "directory" and not name of the baseName's
                //module. For instance, baseName of "one/two/three", maps to
                //"one/two/three.js", but we want the directory, "one/two" for
                //this normalization.
                baseParts = baseParts.slice(0, baseParts.length - 1);

                name = baseParts.concat(name.split("/"));

                //start trimDots
                for (i = 0; i < name.length; i += 1) {
                    part = name[i];
                    if (part === ".") {
                        name.splice(i, 1);
                        i -= 1;
                    } else if (part === "..") {
                        if (i === 1 && (name[2] === '..' || name[0] === '..')) {
                            //End of the line. Keep at least one non-dot
                            //path segment at the front so it can be mapped
                            //correctly to disk. Otherwise, there is likely
                            //no path mapping for a path starting with '..'.
                            //This can still fail, but catches the most reasonable
                            //uses of ..
                            break;
                        } else if (i > 0) {
                            name.splice(i - 1, 2);
                            i -= 2;
                        }
                    }
                }
                //end trimDots

                name = name.join("/");
            }
        }

        //Apply map config if available.
        if ((baseParts || starMap) && map) {
            nameParts = name.split('/');

            for (i = nameParts.length; i > 0; i -= 1) {
                nameSegment = nameParts.slice(0, i).join("/");

                if (baseParts) {
                    //Find the longest baseName segment match in the config.
                    //So, do joins on the biggest to smallest lengths of baseParts.
                    for (j = baseParts.length; j > 0; j -= 1) {
                        mapValue = map[baseParts.slice(0, j).join('/')];

                        //baseName segment has  config, find if it has one for
                        //this name.
                        if (mapValue) {
                            mapValue = mapValue[nameSegment];
                            if (mapValue) {
                                //Match, update name to the new value.
                                foundMap = mapValue;
                                foundI = i;
                                break;
                            }
                        }
                    }
                }

                if (foundMap) {
                    break;
                }

                //Check for a star map match, but just hold on to it,
                //if there is a shorter segment match later in a matching
                //config, then favor over this star map.
                if (!foundStarMap && starMap && starMap[nameSegment]) {
                    foundStarMap = starMap[nameSegment];
                    starI = i;
                }
            }

            if (!foundMap && foundStarMap) {
                foundMap = foundStarMap;
                foundI = starI;
            }

            if (foundMap) {
                nameParts.splice(0, foundI, foundMap);
                name = nameParts.join('/');
            }
        }

        return name;
    }

    function makeRequire(relName, forceSync) {
        return function () {
            //A version of a require function that passes a moduleName
            //value for items that may need to
            //look up paths relative to the moduleName
            return req.apply(undef, aps.call(arguments, 0).concat([relName, forceSync]));
        };
    }

    function makeNormalize(relName) {
        return function (name) {
            return normalize(name, relName);
        };
    }

    function makeLoad(depName) {
        return function (value) {
            defined[depName] = value;
        };
    }

    function callDep(name) {
        if (waiting.hasOwnProperty(name)) {
            var args = waiting[name];
            delete waiting[name];
            defining[name] = true;
            main.apply(undef, args);
        }

        if (!defined.hasOwnProperty(name) && !defining.hasOwnProperty(name)) {
            throw new Error('No ' + name);
        }
        return defined[name];
    }

    //Turns a plugin!resource to [plugin, resource]
    //with the plugin being undefined if the name
    //did not have a plugin prefix.
    function splitPrefix(name) {
        var prefix,
            index = name ? name.indexOf('!') : -1;
        if (index > -1) {
            prefix = name.substring(0, index);
            name = name.substring(index + 1, name.length);
        }
        return [prefix, name];
    }

    function onResourceLoad(name, defined, deps){
        if(requirejs.onResourceLoad && name){
            requirejs.onResourceLoad({defined:defined}, {id:name}, deps);
        }
    }

    /**
     * Makes a name map, normalizing the name, and using a plugin
     * for normalization if necessary. Grabs a ref to plugin
     * too, as an optimization.
     */
    makeMap = function (name, relName) {
        var plugin,
            parts = splitPrefix(name),
            prefix = parts[0];

        name = parts[1];

        if (prefix) {
            prefix = normalize(prefix, relName);
            plugin = callDep(prefix);
        }

        //Normalize according
        if (prefix) {
            if (plugin && plugin.normalize) {
                name = plugin.normalize(name, makeNormalize(relName));
            } else {
                name = normalize(name, relName);
            }
        } else {
            name = normalize(name, relName);
            parts = splitPrefix(name);
            prefix = parts[0];
            name = parts[1];
            if (prefix) {
                plugin = callDep(prefix);
            }
        }

        //Using ridiculous property names for space reasons
        return {
            f: prefix ? prefix + '!' + name : name, //fullName
            n: name,
            pr: prefix,
            p: plugin
        };
    };

    function makeConfig(name) {
        return function () {
            return (config && config.config && config.config[name]) || {};
        };
    }

    handlers = {
        require: function (name) {
            return makeRequire(name);
        },
        exports: function (name) {
            var e = defined[name];
            if (typeof e !== 'undefined') {
                return e;
            } else {
                return (defined[name] = {});
            }
        },
        module: function (name) {
            return {
                id: name,
                uri: '',
                exports: defined[name],
                config: makeConfig(name)
            };
        }
    };

    main = function (name, deps, callback, relName) {
        var cjsModule, depName, ret, map, i,
            args = [],
            usingExports;

        //Use name if no relName
        relName = relName || name;

        //Call the callback to define the module, if necessary.
        if (typeof callback === 'function') {

            //Pull out the defined dependencies and pass the ordered
            //values to the callback.
            //Default to [require, exports, module] if no deps
            deps = !deps.length && callback.length ? ['require', 'exports', 'module'] : deps;
            for (i = 0; i < deps.length; i += 1) {
                map = makeMap(deps[i], relName);
                depName = map.f;

                //Fast path CommonJS standard dependencies.
                if (depName === "require") {
                    args[i] = handlers.require(name);
                } else if (depName === "exports") {
                    //CommonJS module spec 1.1
                    args[i] = handlers.exports(name);
                    usingExports = true;
                } else if (depName === "module") {
                    //CommonJS module spec 1.1
                    cjsModule = args[i] = handlers.module(name);
                } else if (defined.hasOwnProperty(depName) ||
                           waiting.hasOwnProperty(depName) ||
                           defining.hasOwnProperty(depName)) {
                    args[i] = callDep(depName);
                } else if (map.p) {
                    map.p.load(map.n, makeRequire(relName, true), makeLoad(depName), {});
                    args[i] = defined[depName];
                } else {
                    throw new Error(name + ' missing ' + depName);
                }
            }

            ret = callback.apply(defined[name], args);

            if (name) {
                //If setting exports via "module" is in play,
                //favor that over return value and exports. After that,
                //favor a non-undefined return value over exports use.
                if (cjsModule && cjsModule.exports !== undef &&
                        cjsModule.exports !== defined[name]) {
                    defined[name] = cjsModule.exports;
                } else if (ret !== undef || !usingExports) {
                    //Use the return value from the function.
                    defined[name] = ret;
                }
            }
        } else if (name) {
            //May just be an object definition for the module. Only
            //worry about defining if have a module name.
            defined[name] = callback;
        }

        onResourceLoad(name, defined, args);
    };

    requirejs = require = req = function (deps, callback, relName, forceSync, alt) {
        if (typeof deps === "string") {
            if (handlers[deps]) {
                //callback in this case is really relName
                return handlers[deps](callback);
            }
            //Just return the module wanted. In this scenario, the
            //deps arg is the module name, and second arg (if passed)
            //is just the relName.
            //Normalize module name, if it contains . or ..
            return callDep(makeMap(deps, callback).f);
        } else if (!deps.splice) {
            //deps is a config object, not an array.
            config = deps;
            if (callback.splice) {
                //callback is an array, which means it is a dependency list.
                //Adjust args if there are dependencies
                deps = callback;
                callback = relName;
                relName = null;
            } else {
                deps = undef;
            }
        }

        //Support require(['a'])
        callback = callback || function () {};

        //If relName is a function, it is an errback handler,
        //so remove it.
        if (typeof relName === 'function') {
            relName = forceSync;
            forceSync = alt;
        }

        //Simulate async callback;
        if (forceSync) {
            main(undef, deps, callback, relName);
        } else {
            setTimeout(function () {
                main(undef, deps, callback, relName);
            }, 15);
        }

        return req;
    };

    /**
     * Just drops the config on the floor, but returns req in case
     * the config return value is used.
     */
    req.config = function (cfg) {
        config = cfg;
        return req;
    };

    define = function (name, deps, callback) {

        //This module may not have dependencies
        if (!deps.splice) {
            //deps is not an array, so probably means
            //an object literal or factory function for
            //the value. Adjust args.
            callback = deps;
            deps = [];
        }

        waiting[name] = [name, deps, callback];
    };

    define.amd = {
        jQuery: true
    };
}());

define("../Scripts/almond-custom", function(){});

define('durandal/system',["require","jquery"],function(e,t){function n(e){var t="[object "+e+"]";r["is"+e]=function(e){return s.call(e)==t}}var r,i=!1,a=Object.keys,o=Object.prototype.hasOwnProperty,s=Object.prototype.toString,c=!1,l=Array.isArray,u=Array.prototype.slice;if(Function.prototype.bind&&("object"==typeof console||"function"==typeof console)&&"object"==typeof console.log)try{["log","info","warn","error","assert","dir","clear","profile","profileEnd"].forEach(function(e){console[e]=this.call(console[e],console)},Function.prototype.bind)}catch(d){c=!0}e.on&&e.on("moduleLoaded",function(e,t){r.setModuleId(e,t)}),"undefined"!=typeof requirejs&&(requirejs.onResourceLoad=function(e,t){r.setModuleId(e.defined[t.id],t.id)});var f=function(){},v=function(){try{if("undefined"!=typeof console&&"function"==typeof console.log)if(window.opera)for(var e=0;e<arguments.length;)console.log("Item "+(e+1)+": "+arguments[e]),e++;else 1==u.call(arguments).length&&"string"==typeof u.call(arguments)[0]?console.log(u.call(arguments).toString()):console.log.apply(console,u.call(arguments));else Function.prototype.bind&&!c||"undefined"==typeof console||"object"!=typeof console.log||Function.prototype.call.call(console.log,console,u.call(arguments))}catch(t){}},g=function(e){if(e instanceof Error)throw e;throw new Error(e)};r={version:"2.0.0",noop:f,getModuleId:function(e){return e?"function"==typeof e?e.prototype.__moduleId__:"string"==typeof e?null:e.__moduleId__:null},setModuleId:function(e,t){return e?"function"==typeof e?(e.prototype.__moduleId__=t,void 0):("string"!=typeof e&&(e.__moduleId__=t),void 0):void 0},resolveObject:function(e){return r.isFunction(e)?new e:e},debug:function(e){return 1==arguments.length&&(i=e,i?(this.log=v,this.error=g,this.log("Debug:Enabled")):(this.log("Debug:Disabled"),this.log=f,this.error=f)),i},log:f,error:f,assert:function(e,t){e||r.error(new Error(t||"Assert:Failed"))},defer:function(e){return t.Deferred(e)},guid:function(){return"xxxxxxxx-xxxx-4xxx-yxxx-xxxxxxxxxxxx".replace(/[xy]/g,function(e){var t=0|16*Math.random(),n="x"==e?t:8|3&t;return n.toString(16)})},acquire:function(){var t,n=arguments[0],i=!1;return r.isArray(n)?(t=n,i=!0):t=u.call(arguments,0),this.defer(function(n){e(t,function(){var e=arguments;setTimeout(function(){e.length>1||i?n.resolve(u.call(e,0)):n.resolve(e[0])},1)},function(e){n.reject(e)})}).promise()},extend:function(e){for(var t=u.call(arguments,1),n=0;n<t.length;n++){var r=t[n];if(r)for(var i in r)e[i]=r[i]}return e},wait:function(e){return r.defer(function(t){setTimeout(t.resolve,e)}).promise()}},r.keys=a||function(e){if(e!==Object(e))throw new TypeError("Invalid object");var t=[];for(var n in e)o.call(e,n)&&(t[t.length]=n);return t},r.isElement=function(e){return!(!e||1!==e.nodeType)},r.isArray=l||function(e){return"[object Array]"==s.call(e)},r.isObject=function(e){return e===Object(e)},r.isBoolean=function(e){return"boolean"==typeof e},r.isPromise=function(e){return e&&r.isFunction(e.then)};for(var h=["Arguments","Function","String","Number","Date","RegExp"],p=0;p<h.length;p++)n(h[p]);return r});
define('durandal/viewEngine',["durandal/system","jquery"],function(e,t){var n;return n=t.parseHTML?function(e){return t.parseHTML(e)}:function(e){return t(e).get()},{viewExtension:".html",viewPlugin:"text",isViewUrl:function(e){return-1!==e.indexOf(this.viewExtension,e.length-this.viewExtension.length)},convertViewUrlToViewId:function(e){return e.substring(0,e.length-this.viewExtension.length)},convertViewIdToRequirePath:function(e){return this.viewPlugin+"!"+e+this.viewExtension},parseMarkup:n,processMarkup:function(e){var t=this.parseMarkup(e);return this.ensureSingleElement(t)},ensureSingleElement:function(e){if(1==e.length)return e[0];for(var n=[],r=0;r<e.length;r++){var i=e[r];if(8!=i.nodeType){if(3==i.nodeType){var a=/\S/.test(i.nodeValue);if(!a)continue}n.push(i)}}return n.length>1?t(n).wrapAll('<div class="durandal-wrapper"></div>').parent().get(0):n[0]},createView:function(t){var n=this,r=this.convertViewIdToRequirePath(t);return e.defer(function(i){e.acquire(r).then(function(e){var r=n.processMarkup(e);r.setAttribute("data-view",t),i.resolve(r)}).fail(function(e){n.createFallbackView(t,r,e).then(function(e){e.setAttribute("data-view",t),i.resolve(e)})})}).promise()},createFallbackView:function(t,n){var r=this,i='View Not Found. Searched for "'+t+'" via path "'+n+'".';return e.defer(function(e){e.resolve(r.processMarkup('<div class="durandal-view-404">'+i+"</div>"))}).promise()}}});
define('durandal/viewLocator',["durandal/system","durandal/viewEngine"],function(e,t){function n(e,t){for(var n=0;n<e.length;n++){var r=e[n],i=r.getAttribute("data-view");if(i==t)return r}}function r(e){return(e+"").replace(/([\\\.\+\*\?\[\^\]\$\(\)\{\}\=\!\<\>\|\:])/g,"\\$1")}return{useConvention:function(e,t,n){e=e||"viewmodels",t=t||"views",n=n||t;var i=new RegExp(r(e),"gi");this.convertModuleIdToViewId=function(e){return e.replace(i,t)},this.translateViewIdToArea=function(e,t){return t&&"partial"!=t?n+"/"+t+"/"+e:n+"/"+e}},locateViewForObject:function(t,n,r){var i;if(t.getView&&(i=t.getView()))return this.locateView(i,n,r);if(t.viewUrl)return this.locateView(t.viewUrl,n,r);var a=e.getModuleId(t);return a?this.locateView(this.convertModuleIdToViewId(a),n,r):this.locateView(this.determineFallbackViewId(t),n,r)},convertModuleIdToViewId:function(e){return e},determineFallbackViewId:function(e){var t=/function (.{1,})\(/,n=t.exec(e.constructor.toString()),r=n&&n.length>1?n[1]:"";return"views/"+r},translateViewIdToArea:function(e){return e},locateView:function(r,i,a){if("string"==typeof r){var o;if(o=t.isViewUrl(r)?t.convertViewUrlToViewId(r):r,i&&(o=this.translateViewIdToArea(o,i)),a){var s=n(a,o);if(s)return e.defer(function(e){e.resolve(s)}).promise()}return t.createView(o)}return e.defer(function(e){e.resolve(r)}).promise()}}});
define('durandal/binder',["durandal/system","knockout"],function(e,t){function n(t){return void 0===t?{applyBindings:!0}:e.isBoolean(t)?{applyBindings:t}:(void 0===t.applyBindings&&(t.applyBindings=!0),t)}function r(r,c,u,d){if(!c||!u)return a.throwOnErrors?e.error(i):e.log(i,c,d),void 0;if(!c.getAttribute)return a.throwOnErrors?e.error(o):e.log(o,c,d),void 0;var v=c.getAttribute("data-view");try{var f;return r&&r.binding&&(f=r.binding(c)),f=n(f),a.binding(d,c,f),f.applyBindings?(e.log("Binding",v,d),t.applyBindings(u,c)):r&&t.utils.domData.set(c,l,{$data:r}),a.bindingComplete(d,c,f),r&&r.bindingComplete&&r.bindingComplete(c),t.utils.domData.set(c,s,f),f}catch(h){h.message=h.message+";\nView: "+v+";\nModuleId: "+e.getModuleId(d),a.throwOnErrors?e.error(h):e.log(h.message)}}var a,i="Insufficient Information to Bind",o="Unexpected View Type",s="durandal-binding-instruction",l="__ko_bindingContext__";return a={binding:e.noop,bindingComplete:e.noop,throwOnErrors:!1,getBindingInstruction:function(e){return t.utils.domData.get(e,s)},bindContext:function(e,t,n){return n&&e&&(e=e.createChildContext(n)),r(n,t,e,n||(e?e.$data:null))},bind:function(e,t){return r(e,t,e,e)}}});
define('durandal/activator',["durandal/system","knockout"],function(e,t){function r(e){return void 0==e&&(e={}),e.closeOnDeactivate||(e.closeOnDeactivate=l.defaults.closeOnDeactivate),e.beforeActivate||(e.beforeActivate=l.defaults.beforeActivate),e.afterDeactivate||(e.afterDeactivate=l.defaults.afterDeactivate),e.affirmations||(e.affirmations=l.defaults.affirmations),e.interpretResponse||(e.interpretResponse=l.defaults.interpretResponse),e.areSameItem||(e.areSameItem=l.defaults.areSameItem),e}function n(t,r,n){return e.isArray(n)?t[r].apply(t,n):t[r](n)}function a(t,r,n,a,i){if(t&&t.deactivate){e.log("Deactivating",t);var o;try{o=t.deactivate(r)}catch(s){return e.error(s),a.resolve(!1),void 0}o&&o.then?o.then(function(){n.afterDeactivate(t,r,i),a.resolve(!0)},function(t){e.log(t),a.resolve(!1)}):(n.afterDeactivate(t,r,i),a.resolve(!0))}else t&&n.afterDeactivate(t,r,i),a.resolve(!0)}function i(t,r,a,i){if(t)if(t.activate){e.log("Activating",t);var o;try{o=n(t,"activate",i)}catch(s){return e.error(s),a(!1),void 0}o&&o.then?o.then(function(){r(t),a(!0)},function(t){e.log(t),a(!1)}):(r(t),a(!0))}else r(t),a(!0);else a(!0)}function o(t,r,n){return n.lifecycleData=null,e.defer(function(a){if(t&&t.canDeactivate){var i;try{i=t.canDeactivate(r)}catch(o){return e.error(o),a.resolve(!1),void 0}i.then?i.then(function(e){n.lifecycleData=e,a.resolve(n.interpretResponse(e))},function(t){e.error(t),a.resolve(!1)}):(n.lifecycleData=i,a.resolve(n.interpretResponse(i)))}else a.resolve(!0)}).promise()}function s(t,r,a,i){return a.lifecycleData=null,e.defer(function(o){if(t==r())return o.resolve(!0),void 0;if(t&&t.canActivate){var s;try{s=n(t,"canActivate",i)}catch(c){return e.error(c),o.resolve(!1),void 0}s.then?s.then(function(e){a.lifecycleData=e,o.resolve(a.interpretResponse(e))},function(t){e.error(t),o.resolve(!1)}):(a.lifecycleData=s,o.resolve(a.interpretResponse(s)))}else o.resolve(!0)}).promise()}function c(n,c){var l,u=t.observable(null);c=r(c);var d=t.computed({read:function(){return u()},write:function(e){d.viaSetter=!0,d.activateItem(e)}});return d.__activator__=!0,d.settings=c,c.activator=d,d.isActivating=t.observable(!1),d.canDeactivateItem=function(e,t){return o(e,t,c)},d.deactivateItem=function(t,r){return e.defer(function(e){d.canDeactivateItem(t,r).then(function(n){n?a(t,r,c,e,u):(d.notifySubscribers(),e.resolve(!1))})}).promise()},d.canActivateItem=function(e,t){return s(e,u,c,t)},d.activateItem=function(t,r){var n=d.viaSetter;return d.viaSetter=!1,e.defer(function(o){if(d.isActivating())return o.resolve(!1),void 0;d.isActivating(!0);var s=u();return c.areSameItem(s,t,l,r)?(d.isActivating(!1),o.resolve(!0),void 0):(d.canDeactivateItem(s,c.closeOnDeactivate).then(function(v){v?d.canActivateItem(t,r).then(function(v){v?e.defer(function(e){a(s,c.closeOnDeactivate,c,e)}).promise().then(function(){t=c.beforeActivate(t,r),i(t,u,function(e){l=r,d.isActivating(!1),o.resolve(e)},r)}):(n&&d.notifySubscribers(),d.isActivating(!1),o.resolve(!1))}):(n&&d.notifySubscribers(),d.isActivating(!1),o.resolve(!1))}),void 0)}).promise()},d.canActivate=function(){var e;return n?(e=n,n=!1):e=d(),d.canActivateItem(e)},d.activate=function(){var e;return n?(e=n,n=!1):e=d(),d.activateItem(e)},d.canDeactivate=function(e){return d.canDeactivateItem(d(),e)},d.deactivate=function(e){return d.deactivateItem(d(),e)},d.includeIn=function(e){e.canActivate=function(){return d.canActivate()},e.activate=function(){return d.activate()},e.canDeactivate=function(e){return d.canDeactivate(e)},e.deactivate=function(e){return d.deactivate(e)}},c.includeIn?d.includeIn(c.includeIn):n&&d.activate(),d.forItems=function(t){c.closeOnDeactivate=!1,c.determineNextItemToActivate=function(e,t){var r=t-1;return-1==r&&e.length>1?e[1]:r>-1&&r<e.length-1?e[r]:null},c.beforeActivate=function(e){var r=d();if(e){var n=t.indexOf(e);-1==n?t.push(e):e=t()[n]}else e=c.determineNextItemToActivate(t,r?t.indexOf(r):0);return e},c.afterDeactivate=function(e,r){r&&t.remove(e)};var r=d.canDeactivate;d.canDeactivate=function(n){return n?e.defer(function(e){function r(){for(var t=0;t<i.length;t++)if(!i[t])return e.resolve(!1),void 0;e.resolve(!0)}for(var a=t(),i=[],o=0;o<a.length;o++)d.canDeactivateItem(a[o],n).then(function(e){i.push(e),i.length==a.length&&r()})}).promise():r()};var n=d.deactivate;return d.deactivate=function(r){return r?e.defer(function(e){function n(n){d.deactivateItem(n,r).then(function(){i++,t.remove(n),i==o&&e.resolve()})}for(var a=t(),i=0,o=a.length,s=0;o>s;s++)n(a[s])}).promise():n()},d},d}var l,u={closeOnDeactivate:!0,affirmations:["yes","ok","true"],interpretResponse:function(r){return e.isObject(r)&&(r=r.can||!1),e.isString(r)?-1!==t.utils.arrayIndexOf(this.affirmations,r.toLowerCase()):r},areSameItem:function(e,t){return e==t},beforeActivate:function(e){return e},afterDeactivate:function(e,t,r){t&&r&&r(null)}};return l={defaults:u,create:c,isActivator:function(e){return e&&e.__activator__}}});
define('durandal/composition',["durandal/system","durandal/viewLocator","durandal/binder","durandal/viewEngine","durandal/activator","jquery","knockout"],function(e,t,n,r,a,i,o){function s(e){for(var t=[],n={childElements:t,activeView:null},r=o.virtualElements.firstChild(e);r;)1==r.nodeType&&(t.push(r),r.getAttribute(m)&&(n.activeView=r)),r=o.virtualElements.nextSibling(r);return n.activeView||(n.activeView=t[0]),n}function l(){w--,0===w&&setTimeout(function(){for(var e=b.length;e--;)b[e]();b=[]},1)}function c(t,n,r){if(r)n();else if(t.activate&&t.model&&t.model.activate){var a;a=e.isArray(t.activationData)?t.model.activate.apply(t.model,t.activationData):t.model.activate(t.activationData),a&&a.then?a.then(n):a||void 0===a?n():l()}else n()}function u(){var t=this;t.activeView&&t.activeView.removeAttribute(m),t.child&&(t.model&&t.model.attached&&(t.composingNewView||t.alwaysTriggerAttach)&&t.model.attached(t.child,t.parent,t),t.attached&&t.attached(t.child,t.parent,t),t.child.setAttribute(m,!0),t.composingNewView&&t.model&&(t.model.compositionComplete&&g.current.complete(function(){t.model.compositionComplete(t.child,t.parent,t)}),t.model.detached&&o.utils.domNodeDisposal.addDisposeCallback(t.child,function(){t.model.detached(t.child,t.parent,t)})),t.compositionComplete&&g.current.complete(function(){t.compositionComplete(t.child,t.parent,t)})),l(),t.triggerAttach=e.noop}function d(t){if(e.isString(t.transition)){if(t.activeView){if(t.activeView==t.child)return!1;if(!t.child)return!0;if(t.skipTransitionOnSameViewId){var n=t.activeView.getAttribute("data-view"),r=t.child.getAttribute("data-view");return n!=r}}return!0}return!1}function v(e){for(var t=0,n=e.length,r=[];n>t;t++){var a=e[t].cloneNode(!0);r.push(a)}return r}function f(e){var t=v(e.parts),n=g.getParts(t),r=g.getParts(e.child);for(var a in n)i(r[a]).replaceWith(n[a])}function h(t){var n,r,a=o.virtualElements.childNodes(t);if(!e.isArray(a)){var i=[];for(n=0,r=a.length;r>n;n++)i[n]=a[n];a=i}for(n=1,r=a.length;r>n;n++)o.removeNode(a[n])}var g,p={},m="data-active-view",b=[],w=0,y="durandal-composition-data",x="data-part",A="["+x+"]",k=["model","view","transition","area","strategy","activationData"],I={complete:function(e){b.push(e)}};return g={convertTransitionToModuleId:function(e){return"transitions/"+e},defaultTransitionName:null,current:I,addBindingHandler:function(e,t,n){var r,a,i="composition-handler-"+e;t=t||o.bindingHandlers[e],n=n||function(){return void 0},a=o.bindingHandlers[e]={init:function(e,r,a,s,l){var c={trigger:o.observable(null)};return g.current.complete(function(){t.init&&t.init(e,r,a,s,l),t.update&&(o.utils.domData.set(e,i,t),c.trigger("trigger"))}),o.utils.domData.set(e,i,c),n(e,r,a,s,l)},update:function(e,t,n,r,a){var s=o.utils.domData.get(e,i);return s.update?s.update(e,t,n,r,a):(s.trigger(),void 0)}};for(r in t)"init"!==r&&"update"!==r&&(a[r]=t[r])},getParts:function(t){var n={};e.isArray(t)||(t=[t]);for(var r=0;r<t.length;r++){var a=t[r];if(a.getAttribute){var o=a.getAttribute(x);o&&(n[o]=a);for(var s=i(A,a).not(i("[data-bind] "+A,a)),l=0;l<s.length;l++){var c=s.get(l);n[c.getAttribute(x)]=c}}}return n},cloneNodes:v,finalize:function(t){if(t.transition=t.transition||this.defaultTransitionName,t.child||t.activeView)if(d(t)){var r=this.convertTransitionToModuleId(t.transition);e.acquire(r).then(function(e){t.transition=e,e(t).then(function(){if(t.cacheViews){if(t.activeView){var e=n.getBindingInstruction(t.activeView);void 0==e.cacheViews||e.cacheViews||o.removeNode(t.activeView)}}else t.child?h(t.parent):o.virtualElements.emptyNode(t.parent);t.triggerAttach()})}).fail(function(t){e.error("Failed to load transition ("+r+"). Details: "+t.message)})}else{if(t.child!=t.activeView){if(t.cacheViews&&t.activeView){var a=n.getBindingInstruction(t.activeView);void 0==a.cacheViews||a.cacheViews?i(t.activeView).hide():o.removeNode(t.activeView)}t.child?(t.cacheViews||h(t.parent),i(t.child).show()):t.cacheViews||o.virtualElements.emptyNode(t.parent)}t.triggerAttach()}else t.cacheViews||o.virtualElements.emptyNode(t.parent),t.triggerAttach()},bindAndShow:function(e,t,a){t.child=e,t.composingNewView=t.cacheViews?-1==o.utils.arrayIndexOf(t.viewElements,e):!0,c(t,function(){if(t.binding&&t.binding(t.child,t.parent,t),t.preserveContext&&t.bindingContext)t.composingNewView&&(t.parts&&f(t),i(e).hide(),o.virtualElements.prepend(t.parent,e),n.bindContext(t.bindingContext,e,t.model));else if(e){var a=t.model||p,s=o.dataFor(e);if(s!=a){if(!t.composingNewView)return i(e).remove(),r.createView(e.getAttribute("data-view")).then(function(e){g.bindAndShow(e,t,!0)}),void 0;t.parts&&f(t),i(e).hide(),o.virtualElements.prepend(t.parent,e),n.bind(a,e)}}g.finalize(t)},a)},defaultStrategy:function(e){return t.locateViewForObject(e.model,e.area,e.viewElements)},getSettings:function(t){var n,i=t(),s=o.utils.unwrapObservable(i)||{},l=a.isActivator(i);if(e.isString(s))return s=r.isViewUrl(s)?{view:s}:{model:s,activate:!0};if(n=e.getModuleId(s))return s={model:s,activate:!0};!l&&s.model&&(l=a.isActivator(s.model));for(var c in s)s[c]=-1!=o.utils.arrayIndexOf(k,c)?o.utils.unwrapObservable(s[c]):s[c];return l?s.activate=!1:void 0===s.activate&&(s.activate=!0),s},executeStrategy:function(e){e.strategy(e).then(function(t){g.bindAndShow(t,e)})},inject:function(n){return n.model?n.view?(t.locateView(n.view,n.area,n.viewElements).then(function(e){g.bindAndShow(e,n)}),void 0):(n.strategy||(n.strategy=this.defaultStrategy),e.isString(n.strategy)?e.acquire(n.strategy).then(function(e){n.strategy=e,g.executeStrategy(n)}).fail(function(t){e.error("Failed to load view strategy ("+n.strategy+"). Details: "+t.message)}):this.executeStrategy(n),void 0):(this.bindAndShow(null,n),void 0)},compose:function(n,r,a,i){w++,i||(r=g.getSettings(function(){return r},n));var o=s(n);r.activeView=o.activeView,r.parent=n,r.triggerAttach=u,r.bindingContext=a,r.cacheViews&&!r.viewElements&&(r.viewElements=o.childElements),r.model?e.isString(r.model)?e.acquire(r.model).then(function(t){r.model=e.resolveObject(t),g.inject(r)}).fail(function(t){e.error("Failed to load composed module ("+r.model+"). Details: "+t.message)}):g.inject(r):r.view?(r.area=r.area||"partial",r.preserveContext=!0,t.locateView(r.view,r.area,r.viewElements).then(function(e){g.bindAndShow(e,r)})):this.bindAndShow(null,r)}},o.bindingHandlers.compose={init:function(){return{controlsDescendantBindings:!0}},update:function(e,t,n,a,i){var s=g.getSettings(t,e);if(s.mode){var l=o.utils.domData.get(e,y);if(!l){var c=o.virtualElements.childNodes(e);l={},"inline"===s.mode?l.view=r.ensureSingleElement(c):"templated"===s.mode&&(l.parts=v(c)),o.virtualElements.emptyNode(e),o.utils.domData.set(e,y,l)}"inline"===s.mode?s.view=l.view.cloneNode(!0):"templated"===s.mode&&(s.parts=l.parts),s.preserveContext=!0}g.compose(e,s,i,!0)}},o.virtualElements.allowedBindings.compose=!0,g});
define('durandal/events',["durandal/system"],function(e){var t=/\s+/,n=function(){},r=function(e,t){this.owner=e,this.events=t};return r.prototype.then=function(e,t){return this.callback=e||this.callback,this.context=t||this.context,this.callback?(this.owner.on(this.events,this.callback,this.context),this):this},r.prototype.on=r.prototype.then,r.prototype.off=function(){return this.owner.off(this.events,this.callback,this.context),this},n.prototype.on=function(e,n,a){var i,o,s;if(n){for(i=this.callbacks||(this.callbacks={}),e=e.split(t);o=e.shift();)s=i[o]||(i[o]=[]),s.push(n,a);return this}return new r(this,e)},n.prototype.off=function(n,r,a){var i,o,s,l;if(!(o=this.callbacks))return this;if(!(n||r||a))return delete this.callbacks,this;for(n=n?n.split(t):e.keys(o);i=n.shift();)if((s=o[i])&&(r||a))for(l=s.length-2;l>=0;l-=2)r&&s[l]!==r||a&&s[l+1]!==a||s.splice(l,2);else delete o[i];return this},n.prototype.trigger=function(e){var n,r,a,i,o,s,l,c;if(!(r=this.callbacks))return this;for(c=[],e=e.split(t),i=1,o=arguments.length;o>i;i++)c[i-1]=arguments[i];for(;n=e.shift();){if((l=r.all)&&(l=l.slice()),(a=r[n])&&(a=a.slice()),a)for(i=0,o=a.length;o>i;i+=2)a[i].apply(a[i+1]||this,c);if(l)for(s=[n].concat(c),i=0,o=l.length;o>i;i+=2)l[i].apply(l[i+1]||this,s)}return this},n.prototype.proxy=function(e){var t=this;return function(n){t.trigger(e,n)}},n.includeIn=function(e){e.on=n.prototype.on,e.off=n.prototype.off,e.trigger=n.prototype.trigger,e.proxy=n.prototype.proxy},n});
define('durandal/app',["durandal/system","durandal/viewEngine","durandal/composition","durandal/events","jquery"],function(e,t,r,n,a){function i(){return e.defer(function(t){return 0==s.length?(t.resolve(),void 0):(e.acquire(s).then(function(r){for(var n=0;n<r.length;n++){var a=r[n];if(a.install){var i=l[n];e.isObject(i)||(i={}),a.install(i),e.log("Plugin:Installed "+s[n])}else e.log("Plugin:Loaded "+s[n])}t.resolve()}).fail(function(t){e.error("Failed to load plugin(s). Details: "+t.message)}),void 0)}).promise()}var o,s=[],l=[];return o={title:"Application",configurePlugins:function(t,r){var n=e.keys(t);r=r||"plugins/",-1===r.indexOf("/",r.length-1)&&(r+="/");for(var a=0;a<n.length;a++){var i=n[a];s.push(r+i),l.push(t[i])}},start:function(){return e.log("Application:Starting"),this.title&&(document.title=this.title),e.defer(function(t){a(function(){i().then(function(){t.resolve(),e.log("Application:Started")})})}).promise()},setRoot:function(n,a,i){var o,s={activate:!0,transition:a};o=!i||e.isString(i)?document.getElementById(i||"applicationHost"):i,e.isString(n)?t.isViewUrl(n)?s.view=n:s.model=n:s.model=n,r.compose(o,s)}},n.includeIn(o),o});
define('services/appsecurity',['require'],function(e){var t=(e("durandal/system"),e("durandal/app"),e("plugins/router")),n="/api/account",r=function(e,t,n){this.userName=e,this.password=t,this.rememberMe=n},a=ko.observable({IsAuthenticated:!1,UserName:"",Roles:[],AntiforgeryToken:null}),i=ko.observable(),o=function(){$.get(n+"/getantiforgerytokens").then(function(e){a().AntiforgeryToken=e,$(document).ajaxSend(function(t,n,r){r.hasContent&&n.setRequestHeader("__RequestVerificationToken",e)})})};return{credential:r,user:a,externalLogins:i,isUserInRole:function(e){var t=this,n=!1;return $.each(e,function(e,r){-1!=t.user().Roles.indexOf(r)&&(n=!0)}),n},login:function(e){var t=this,r=$.post(n+"/login",e).done(function(e){t.user(e),t.addAntiForgeryTokenToAjaxRequests()}).fail(function(){t.user({IsAuthenticated:!1,UserName:"",Roles:[]})});return r},logout:function(){var e=this,a=$.post(n+"/logout",r).done(function(n){e.user(n),e.addAntiForgeryTokenToAjaxRequests(),void 0!=t.activeInstruction().config.authorize&&t.navigate("")}).fail(function(e){return e});return a},register:function(e,r,a,i,o){var s=this,l=$.post(n+"/register",{username:e,email:r,password:a,confirmpassword:i}).done(function(e){s.user(e),s.addAntiForgeryTokenToAjaxRequests(),t.navigate(o)});return l},getAuthInfo:function(){var e=$.get(n+"/userinfo");return e},getExternalLogins:function(){var e=$.get(n+"/externalloginslist");return e},addAntiForgeryTokenToAjaxRequests:o,externalLogin:function(e,r){location.href=n+"/externallogin?provider="+e+"&returnurl="+encodeURIComponent(r)+"&pushstate="+t.options.pushState},getExternalLoginConfirmationData:function(e,t,r,a){var i=$.get(n+"/externalloginconfirmation?returnurl="+encodeURIComponent(e)+"&username="+t+"&provideruserid="+r+"&provider="+a);return i},confirmExternalAccount:function(e,t,r,a){var i=this,o=$.post(n+"/registerexternallogin",{displayname:e,username:t,email:r,externallogindata:a}).done(function(e){i.user(e),i.addAntiForgeryTokenToAjaxRequests()});return o},hasLocalAccount:function(){var e=$.get(n+"/haslocalaccount");return e},changePassword:function(e,t,r){var a=$.post(n+"/changepassword",{oldpassword:e,newpassword:t,confirmpassword:r});return a},createLocalAccount:function(e,t){var r=$.post(n+"/createlocalaccount",{newpassword:e,confirmpassword:t});return r},externalAccounts:function(){var e=$.get(n+"/externalaccounts");return e},dissasociate:function(e,t){var r=$.post(n+"/disassociate",{provider:e,provideruserid:t});return r}}});
requirejs.config({baseUrl:"/App",paths:{text:"../Scripts/text",durandal:"../Scripts/durandal",plugins:"../Scripts/durandal/plugins",transitions:"../Scripts/durandal/transitions"}}),define("jquery",[],function(){return jQuery}),define("knockout",ko),define('main',["durandal/app","durandal/viewLocator","durandal/system","services/appsecurity"],function(e,t,n,r){n.debug(!0),e.title="Durandal Auth",e.configurePlugins({router:!0,dialog:!0,widget:{kinds:["expander"]}}),e.start().then(function(){t.useConvention(),r.addAntiForgeryTokenToAjaxRequests();var n=new Stashy.Loader("body");$(document).ajaxStart(function(){n.on("fixed","1px","#FFF","prepend")}).ajaxComplete(function(){n.off()}),ko.validation.init({decorateElement:!0,errorElementClass:"has-error",registerExtenders:!0,messagesOnModified:!0,insertMessages:!0,parseInputAttributes:!0,messageTemplate:null}),marked.setOptions({highlight:function(e){return hljs.highlightAuto(e).value},sanitize:!0,breaks:!0}),$(document).on("keyup",".auto-height-textarea",function(){$(this).css("height","auto"),$(this).height(this.scrollHeight)}),r.getAuthInfo().then(function(t){r.user(t),e.setRoot("viewmodels/shell")})})});
define('services/utils',[],function(){function e(e){return decodeURI((RegExp(e+"="+"(.+?)(&|$)").exec(location.href)||[,null])[1])}function t(e){1===e.nodeType&&$(e).addClass("animated fadeInLeft")}function n(e){1===e.nodeType&&($(e).addClass("animated fadeOutLeft"),setTimeout(function(){$(e).remove()},500))}function r(){return moment.utc().format()}function a(e){try{var t=e.entityErrors[0];return"Validation Error: "+t.errorMessage}catch(n){return"Save validation error"}}function i(e){try{var t=e.entityAspect.getValidationErrors(),n=t.map(function(e){return e.errorMessage});return n.length?n.join("; "):"no validation errors"}catch(r){return"not an entity"}}return{getUrlParameter:e,addItemAnimation:t,removeItemAnimation:n,getCurrentDate:r,getSaveValidationErrorMessage:a,getEntityValidationErrorMessage:i}});
define('model/modelBuilder',["services/appsecurity","services/utils"],function(e,t){function n(e){r(e),a(e),i(e)}function r(n){var r=function(){this.articleId=ko.observable(breeze.core.getUuid()),this.imageUrl=ko.observable("/Content/icons/no_photo.png"),this.createdBy=ko.observable(e.user().UserName),this.updatedBy=ko.observable(e.user().UserName),this.isPublished=ko.observable(!1);var n=t.getCurrentDate();this.createdDate=ko.observable(n),this.updatedDate=ko.observable(n)};r.prototype.addTag=function(e){var t=this.entityAspect.entityManager.createEntity("Tag",{name:e,articleId:this.articleId()});return this.tags.push(t),t},r.prototype.deleteTag=function(e){o(e,"Tag"),this.throwIfNotOwnerOf(e),e.entityAspect.setDeleted()},r.prototype.throwIfNotOwnerOf=function(e){if(!e.articleId||e.articleId()!==this.articleId())throw new Error("Object is not associated with current Article")};var a=function(e){s(e),l(e),e.splitTags=ko.computed(function(){var t=[];return ko.utils.arrayForEach(e.tags(),function(e){t.push(e.name())}),t.join(",")}),e.formattedCreatedDate=ko.computed(function(){return moment(e.createdDate()).format("MMM Do YY")}),e.unsavedChanges=ko.observable(e.entityAspect.entityState.isAddedModifiedOrDeleted())};n.registerEntityTypeCtor("Article",r,a)}function a(e){var t=function(){this.categoryId=ko.observable(breeze.core.getUuid())};e.registerEntityTypeCtor("Category",t)}function i(e){var t=function(){this.tagId=ko.observable(breeze.core.getUuid())};e.registerEntityTypeCtor("Tag",t)}function o(e,t){if(!e.entityType||e.entityType.shortName!==t)throw new Error("Object must be an entity of type "+t)}function s(e){var t,n,r,a,i,o,s,l,d=e.entityType;if(d){for(t=0;t<d.dataProperties.length;t+=1){for(n=d.dataProperties[t],r=n.name,a=e[r],i=[],o=0;o<n.validators.length;o+=1)s=n.validators[o],l={propertyName:r,validator:function(e){var t=this.innerValidator.validate(e,{displayName:this.propertyName});return this.message=t?t.errorMessage:"",null===t},message:"",innerValidator:s},i.push(l);a.extend({validation:i})}for(t=0;t<d.foreignKeyProperties.length;t+=1){for(n=d.foreignKeyProperties[t],r=n.name,a=e[r],i=[],o=0;o<n.validators.length;o+=1)s=n.validators[o],l={propertyName:r,validator:function(e){var t=this.innerValidator.validate(e,{displayName:this.propertyName});return this.message=t?t.errorMessage:"",null===t},message:"",innerValidator:s},i.push(l);a.extend({validation:i}),n.isNullable||a.extend({notEqual:c})}}}function l(e){var t=ko.observable(!1),n=function(){var n=e.entityAspect.getValidationErrors().length>0;t()===n?t.valueHasMutated():t(n)};n(),e.entityAspect.validationErrorsChanged.subscribe(n),e.hasValidationErrors=t}var c=0,d={extendMetadata:n};return d});
define('services/config',[],function(){var e="durandalauth/",t={lookupLocation:e+"lookups",saveChangesLocation:e+"savechanges",publicArticlesLocation:e+"publicarticles",privateArticlesLocation:e+"privatearticles",userProfileLocation:e+"userprofiles",categoriesLocation:e+"categories"};return t});
define('services/entitymanagerprovider',["durandal/app","services/config"],function(e,t){function n(){return new o}function r(){return i.fetchMetadata().then(function(){s.modelBuilder&&s.modelBuilder(i.metadataStore);var e=breeze.EntityQuery.from(t.lookupLocation);return i.executeQuery(e)})}breeze.NamingConvention.camelCase.setAsDefault();var a="/breeze",i=new breeze.EntityManager(a),o=function(){var t=function(){var t;this.manager=function(){return t||(t=i.createEmptyCopy(),t.importEntities(i.exportEntities()),t.hasChangesChanged.subscribe(function(){e.trigger("hasChanges")})),t}};return t}(),s={prepare:r,create:n};return s});
define('services/logger',["durandal/system"],function(e){function t(e,t,n,r){a(e,t,n,r,"info")}function n(e,t,n,r){a(e,t,n,r,"error")}function r(e,t,n,r){a(e,t,n,r,"success")}function a(t,n,r,a,i){r=r?"["+r+"] ":"",n?e.log(r,t,n):e.log(r,t),a&&("error"===i?toastr.error(t,"Something failed",{timeOut:0,positionClass:"toast-bottom-full-width"}):"success"===i?toastr.success(t,"Success",{timeOut:0,positionClass:"toast-bottom-full-width"}):toastr.info(t,"Info",{timeOut:0,positionClass:"toast-bottom-full-width"}))}var i={log:t,logError:n,logSuccess:r};return i});
define('services/errorhandler',["services/logger","durandal/system","services/utils"],function(e,t,n){function r(e){return $.extend(e,new a(e))}var a=function(){var r=function(r){this.handleError=function(a){throw a.entityErrors&&(a.message=n.getSaveValidationErrorMessage(a)),e.logError(a.message,null,t.getModuleId(r),!0),a},this.log=function(n,a){e.log(n,null,t.getModuleId(r),a)},this.handlevalidationerrors=function(t){""!=t.responseText?$.each($.parseJSON(t.responseText),function(n,r){e.logError(r,null,t,!0)}):e.logError(t.statusText,null,t,!0)}};return r}();return{includeIn:r}});
define('services/repository',[],function(){function e(e,n,r,a){return new t(e,n,r,a)}var t=function(){var e=function(e,t,n,r){function a(t){return e.manager().executeQuery(t.using(r||breeze.FetchStrategy.FromServer)).then(function(e){return e.results})}function i(t){return e.manager().executeQueryLocally(t)}function o(){return s().metadataStore}function s(){return e.manager()}function l(e,t){if(!e.entityType||e.entityType.shortName!==t)throw new Error("Object must be an entity of type "+t)}var c;t&&(c=o().getEntityType(t),c.setProperties({defaultResourceName:n}),o().setEntityTypeForResourceName(n,t)),this.withId=function(e){if(!t)throw new Error("Repository must be created with an entity type specified");return s().fetchEntityByKey(t,e,!0).then(function(e){if(!e.entity)throw new Error("Entity not found!");return e.entity})},this.find=function(e){var t=breeze.EntityQuery.from(n).where(e);return a(t)},this.findInCache=function(e){var t=breeze.EntityQuery.from(n).where(e);return i(t)},this.all=function(){var e=breeze.EntityQuery.from(n);return a(e)},this.create=function(e){var n=s().createEntity(t,e);return n},this.delete=function(e){l(e,t),e.entityAspect.setDeleted(e)}};return e}();return{create:e,getCtor:t}});
define('services/privatearticlerepository',["services/repository"],function(e){function t(e,t,r,a){return new n(e,t,r,a)}var n=function(){var t=function(t,n,r,a){function i(e){return t.manager().executeQuery(e.using(a||breeze.FetchStrategy.FromServer)).then(function(e){return e.results})}e.getCtor.call(this,t,n,r,a),this.all=function(){var e=breeze.EntityQuery.from(r).orderBy("createdDate desc").expand("Tags");return i(e)}};return t.prototype=e.create(),t}();return{create:t}});
define('services/publicarticlerepository',["services/repository"],function(e){function t(e,t,r,a){return new n(e,t,r,a)}var n=function(){var t=function(t,n,r,a){function i(e){return t.manager().executeQuery(e.using(a||breeze.FetchStrategy.FromServer)).then(function(e){return e.results})}e.getCtor.call(this,t,n,r,a),this.find=function(e,t,n){var a=breeze.EntityQuery.from(r).where(e).orderBy("createdDate desc").expand("Category,Tags").skip(t*n).take(n);return i(a)}};return t.prototype=e.create(),t}();return{create:t}});
define('services/unitofwork',["services/entitymanagerprovider","services/repository","services/privatearticlerepository","services/publicarticlerepository","durandal/app","services/config"],function(e,t,n,r,a,i){function o(){return new u}function s(e){return c[e]||(c[e]=new d),c[e]}function l(){for(key in c)0==c[key].referenceCount&&delete c[key]}var c={},u=function(){var o=function(){var o=e.create();this.hasChanges=function(){return o.manager().hasChanges()},this.commit=function(){var e=new breeze.SaveOptions({resourceName:"durandalauth/savechanges"});return o.manager().saveChanges(null,e).then(function(e){a.trigger("saved",e.entities)})},this.rollback=function(){o.manager().rejectChanges()},this.privatearticles=n.create(o,"Article",i.privateArticlesLocation),this.publicarticles=r.create(o,"Article",i.publicArticlesLocation),this.userprofiles=t.create(o,"UserProfile",i.userProfileLocation),this.categories=t.create(o,"Category",i.categoriesLocation,breeze.FetchStrategy.FromLocalCache)};return o}(),d=function(){var e=function(){var e=null;this.referenceCount=0,this.value=function(){return null===e&&(e=new u),this.referenceCount++,e},this.clear=function(){e=null,this.referenceCount=0,l()}};return e.prototype.release=function(){this.referenceCount--,0===this.referenceCount&&this.clear()},e}();return{create:o,get:s}});
define('plugins/history',["durandal/system","jquery"],function(e,t){function n(e,t,n){if(n){var r=e.href.replace(/(javascript:|#).*$/,"");e.replace(r+"#"+t)}else e.hash="#"+t}var r=/^[#\/]|\s+$/g,a=/^\/+|\/+$/g,i=/msie [\w.]+/,o=/\/$/,s={interval:50,active:!1};return"undefined"!=typeof window&&(s.location=window.location,s.history=window.history),s.getHash=function(e){var t=(e||s).location.href.match(/#(.*)$/);return t?t[1]:""},s.getFragment=function(e,t){if(null==e)if(s._hasPushState||!s._wantsHashChange||t){e=s.location.pathname;var n=s.root.replace(o,"");e.indexOf(n)||(e=e.substr(n.length))}else e=s.getHash();return e.replace(r,"")},s.activate=function(n){s.active&&e.error("History has already been activated."),s.active=!0,s.options=e.extend({},{root:"/"},s.options,n),s.root=s.options.root,s._wantsHashChange=s.options.hashChange!==!1,s._wantsPushState=!!s.options.pushState,s._hasPushState=!!(s.options.pushState&&s.history&&s.history.pushState);var o=s.getFragment(),c=document.documentMode,l=i.exec(navigator.userAgent.toLowerCase())&&(!c||7>=c);s.root=("/"+s.root+"/").replace(a,"/"),l&&s._wantsHashChange&&(s.iframe=t('<iframe src="javascript:0" tabindex="-1" />').hide().appendTo("body")[0].contentWindow,s.navigate(o,!1)),s._hasPushState?t(window).on("popstate",s.checkUrl):s._wantsHashChange&&"onhashchange"in window&&!l?t(window).on("hashchange",s.checkUrl):s._wantsHashChange&&(s._checkUrlInterval=setInterval(s.checkUrl,s.interval)),s.fragment=o;var u=s.location,d=u.pathname.replace(/[^\/]$/,"$&/")===s.root;if(s._wantsHashChange&&s._wantsPushState){if(!s._hasPushState&&!d)return s.fragment=s.getFragment(null,!0),s.location.replace(s.root+s.location.search+"#"+s.fragment),!0;s._hasPushState&&d&&u.hash&&(this.fragment=s.getHash().replace(r,""),this.history.replaceState({},document.title,s.root+s.fragment+u.search))}return s.options.silent?void 0:s.loadUrl()},s.deactivate=function(){t(window).off("popstate",s.checkUrl).off("hashchange",s.checkUrl),clearInterval(s._checkUrlInterval),s.active=!1},s.checkUrl=function(){var e=s.getFragment();return e===s.fragment&&s.iframe&&(e=s.getFragment(s.getHash(s.iframe))),e===s.fragment?!1:(s.iframe&&s.navigate(e,!1),s.loadUrl(),void 0)},s.loadUrl=function(e){var t=s.fragment=s.getFragment(e);return s.options.routeHandler?s.options.routeHandler(t):!1},s.navigate=function(t,r){if(!s.active)return!1;if(void 0===r?r={trigger:!0}:e.isBoolean(r)&&(r={trigger:r}),t=s.getFragment(t||""),s.fragment!==t){s.fragment=t;var a=s.root+t;if(s._hasPushState)s.history[r.replace?"replaceState":"pushState"]({},document.title,a);else{if(!s._wantsHashChange)return s.location.assign(a);n(s.location,t,r.replace),s.iframe&&t!==s.getFragment(s.getHash(s.iframe))&&(r.replace||s.iframe.document.open().close(),n(s.iframe.location,t,r.replace))}return r.trigger?s.loadUrl(t):void 0}},s.navigateBack=function(){s.history.back()},s});
define('plugins/router',["durandal/system","durandal/app","durandal/activator","durandal/events","durandal/composition","plugins/history","knockout","jquery"],function(e,t,n,r,a,i,o,s){function c(e){return e=e.replace(b,"\\$&").replace(g,"(?:$1)?").replace(p,function(e,t){return t?e:"([^/]+)"}).replace(m,"(.*?)"),new RegExp("^"+e+"$")}function l(e){var t=e.indexOf(":"),n=t>0?t-1:e.length;return e.substring(0,n)}function u(e){return e.router&&e.router.loadUrl}function d(e,t){return-1!==e.indexOf(t,e.length-t.length)}function f(e,t){if(!e||!t)return!1;if(e.length!=t.length)return!1;for(var n=0,r=e.length;r>n;n++)if(e[n]!=t[n])return!1;return!0}var v,h,g=/\((.*?)\)/g,p=/(\(\?)?:\w+/g,m=/\*\w+/g,b=/[\-{}\[\]+?.,\\\^$|#\s]/g,w=/\/$/,y=function(){function a(t,n){e.log("Navigation Complete",t,n);var r=e.getModuleId(T);r&&N.trigger("router:navigation:from:"+r),T=t,P=n;var a=e.getModuleId(T);a&&N.trigger("router:navigation:to:"+a),u(t)||N.updateDocumentTitle(t,n),h.explicitNavigation=!1,h.navigatingBack=!1,N.trigger("router:navigation:complete",t,n,N)}function s(t,n){e.log("Navigation Cancelled"),N.activeInstruction(P),P&&N.navigate(P.fragment,!1),R(!1),h.explicitNavigation=!1,h.navigatingBack=!1,N.trigger("router:navigation:cancelled",t,n,N)}function g(t){e.log("Navigation Redirecting"),R(!1),h.explicitNavigation=!1,h.navigatingBack=!1,N.navigate(t,{trigger:!0,replace:!0})}function p(e,t,n){h.navigatingBack=!h.explicitNavigation&&T!=n.fragment,N.trigger("router:route:activating",t,n,N),e.activateItem(t,n.params).then(function(r){if(r){var i=T;a(t,n),u(t)&&A({router:t.router,fragment:n.fragment,queryString:n.queryString}),i==t&&N.attached()}else e.settings.lifecycleData&&e.settings.lifecycleData.redirect?g(e.settings.lifecycleData.redirect):s(t,n);v&&(v.resolve(),v=null)})}function m(t,n,r){var a=N.guardRoute(n,r);a?a.then?a.then(function(a){a?e.isString(a)?g(a):p(t,n,r):s(n,r)}):e.isString(a)?g(a):p(t,n,r):s(n,r)}function b(e,t,n){N.guardRoute?m(e,t,n):p(e,t,n)}function x(e){return P&&P.config.moduleId==e.config.moduleId&&T&&(T.canReuseForRoute&&T.canReuseForRoute.apply(T,e.params)||T.router&&T.router.loadUrl)}function k(){if(!R()){var t=_.shift();if(_=[],t){if(t.router){var r=t.fragment;return t.queryString&&(r+="?"+t.queryString),t.router.loadUrl(r),void 0}R(!0),N.activeInstruction(t),x(t)?b(n.create(),T,t):e.acquire(t.config.moduleId).then(function(n){var r=e.resolveObject(n);b(D,r,t)}).fail(function(n){e.error("Failed to load routed module ("+t.config.moduleId+"). Details: "+n.message)})}}}function A(e){_.unshift(e),k()}function I(e,t,n){for(var r=e.exec(t).slice(1),a=0;a<r.length;a++){var i=r[a];r[a]=i?decodeURIComponent(i):null}var o=N.parseQueryString(n);return o&&r.push(o),{params:r,queryParams:o}}function C(t){N.trigger("router:route:before-config",t,N),e.isRegExp(t)?t.routePattern=t.route:(t.title=t.title||N.convertRouteToTitle(t.route),t.moduleId=t.moduleId||N.convertRouteToModuleId(t.route),t.hash=t.hash||N.convertRouteToHash(t.route),t.routePattern=c(t.route)),N.trigger("router:route:after-config",t,N),N.routes.push(t),N.route(t.routePattern,function(e,n){var r=I(t.routePattern,e,n);A({fragment:e,queryString:n,config:t,params:r.params,queryParams:r.queryParams})})}function E(t){if(e.isArray(t.route))for(var n=0,r=t.route.length;r>n;n++){var a=e.extend({},t);a.route=t.route[n],n>0&&delete a.nav,C(a)}else C(t);return N}function S(e){e.isActive||(e.isActive=o.computed(function(){var t=D();return t&&t.__moduleId__==e.moduleId}))}var T,P,_=[],R=o.observable(!1),D=n.create(),N={handlers:[],routes:[],navigationModel:o.observableArray([]),activeItem:D,isNavigating:o.computed(function(){var e=D(),t=R(),n=e&&e.router&&e.router!=N&&e.router.isNavigating()?!0:!1;return t||n}),activeInstruction:o.observable(null),__router__:!0};return r.includeIn(N),D.settings.areSameItem=function(e,t,n,r){return e==t?f(n,r):!1},N.parseQueryString=function(e){var t,n;if(!e)return null;if(n=e.split("&"),0==n.length)return null;t={};for(var r=0;r<n.length;r++){var a=n[r];if(""!==a){var i=a.split("=");t[i[0]]=i[1]&&decodeURIComponent(i[1].replace(/\+/g," "))}}return t},N.route=function(e,t){N.handlers.push({routePattern:e,callback:t})},N.loadUrl=function(t){var n=N.handlers,r=null,a=t,o=t.indexOf("?");if(-1!=o&&(a=t.substring(0,o),r=t.substr(o+1)),N.relativeToParentRouter){var s=this.parent.activeInstruction();a=s.params.join("/"),a&&"/"==a[0]&&(a=a.substr(1)),a||(a=""),a=a.replace("//","/").replace("//","/")}a=a.replace(w,"");for(var c=0;c<n.length;c++){var l=n[c];if(l.routePattern.test(a))return l.callback(a,r),!0}return e.log("Route Not Found"),N.trigger("router:route:not-found",t,N),P&&i.navigate(P.fragment,{trigger:!1,replace:!0}),h.explicitNavigation=!1,h.navigatingBack=!1,!1},N.updateDocumentTitle=function(e,n){n.config.title?document.title=t.title?n.config.title+" | "+t.title:n.config.title:t.title&&(document.title=t.title)},N.navigate=function(e,t){return e&&-1!=e.indexOf("://")?(window.location.href=e,!0):(h.explicitNavigation=!0,i.navigate(e,t))},N.navigateBack=function(){i.navigateBack()},N.attached=function(){setTimeout(function(){R(!1),N.trigger("router:navigation:attached",T,P,N),k()},10)},N.compositionComplete=function(){N.trigger("router:navigation:composition-complete",T,P,N)},N.convertRouteToHash=function(e){if(N.relativeToParentRouter){var t=N.parent.activeInstruction(),n=t.config.hash+"/"+e;return i._hasPushState&&(n="/"+n),n=n.replace("//","/").replace("//","/")}return i._hasPushState?e:"#"+e},N.convertRouteToModuleId=function(e){return l(e)},N.convertRouteToTitle=function(e){var t=l(e);return t.substring(0,1).toUpperCase()+t.substring(1)},N.map=function(t,n){if(e.isArray(t)){for(var r=0;r<t.length;r++)N.map(t[r]);return N}return e.isString(t)||e.isRegExp(t)?(n?e.isString(n)&&(n={moduleId:n}):n={},n.route=t):n=t,E(n)},N.buildNavigationModel=function(t){var n=[],r=N.routes;t=t||100;for(var a=0;a<r.length;a++){var i=r[a];i.nav&&(e.isNumber(i.nav)||(i.nav=t),S(i),n.push(i))}return n.sort(function(e,t){return e.nav-t.nav}),N.navigationModel(n),N},N.mapUnknownRoutes=function(t,n){var r="*catchall",a=c(r);return N.route(a,function(o,s){var c=I(a,o,s),l={fragment:o,queryString:s,config:{route:r,routePattern:a},params:c.params,queryParams:c.queryParams};if(t)if(e.isString(t))l.config.moduleId=t,n&&i.navigate(n,{trigger:!1,replace:!0});else if(e.isFunction(t)){var u=t(l);if(u&&u.then)return u.then(function(){N.trigger("router:route:before-config",l.config,N),N.trigger("router:route:after-config",l.config,N),A(l)}),void 0}else l.config=t,l.config.route=r,l.config.routePattern=a;else l.config.moduleId=o;N.trigger("router:route:before-config",l.config,N),N.trigger("router:route:after-config",l.config,N),A(l)}),N},N.reset=function(){return P=T=void 0,N.handlers=[],N.routes=[],N.off(),delete N.options,N},N.makeRelative=function(t){return e.isString(t)&&(t={moduleId:t,route:t}),t.moduleId&&!d(t.moduleId,"/")&&(t.moduleId+="/"),t.route&&!d(t.route,"/")&&(t.route+="/"),t.fromParent&&(N.relativeToParentRouter=!0),N.on("router:route:before-config").then(function(e){t.moduleId&&(e.moduleId=t.moduleId+e.moduleId),t.route&&(e.route=""===e.route?t.route.substring(0,t.route.length-1):t.route+e.route)}),N},N.createChildRouter=function(){var e=y();return e.parent=N,e},N};return h=y(),h.explicitNavigation=!1,h.navigatingBack=!1,h.activate=function(t){return e.defer(function(n){if(v=n,h.options=e.extend({routeHandler:h.loadUrl},h.options,t),i.activate(h.options),i._hasPushState)for(var r=h.routes,a=r.length;a--;){var o=r[a];o.hash=o.hash.replace("#","")}s(document).delegate("a","click",function(e){if(h.explicitNavigation=!0,i._hasPushState&&!(e.altKey||e.ctrlKey||e.metaKey||e.shiftKey)){var t=s(this).attr("href"),n=this.protocol+"//";(!t||"#"!==t.charAt(0)&&t.slice(n.length)!==n)&&(e.preventDefault(),i.navigate(t))}})}).promise()},h.deactivate=function(){i.deactivate()},h.install=function(){o.bindingHandlers.router={init:function(){return{controlsDescendantBindings:!0}},update:function(e,t,n,r,i){var s=o.utils.unwrapObservable(t())||{};if(s.__router__)s={model:s.activeItem(),attached:s.attached,compositionComplete:s.compositionComplete,activate:!1};else{var c=o.utils.unwrapObservable(s.router||r.router)||h;s.model=c.activeItem(),s.attached=c.attached,s.compositionComplete=c.compositionComplete,s.activate=!1}a.compose(e,s,i)}},o.virtualElements.allowedBindings.router=!0},h});
define('viewmodels/account/externalloginconfirmation',["services/appsecurity","plugins/router","services/errorhandler","services/utils"],function(e,t,r,n){var a=ko.observable(),i=ko.observable().extend({required:!0}),o=ko.observable().extend({required:!0,email:!0}),s=ko.observable(),l=ko.observable(),c={DisplayName:a,UserName:i,Email:o,ExternalLoginData:s,ReturnUrl:l,activate:function(){var t=this;return ga("send","pageview",{page:window.location.href,title:document.title}),e.getExternalLoginConfirmationData(n.getUrlParameter("returnurl"),n.getUrlParameter("username"),n.getUrlParameter("provideruserid"),n.getUrlParameter("provider")).then(function(e){t.DisplayName(e.DisplayName),t.UserName(e.UserName.split("@")[0]),t.Email(e.UserName),t.ExternalLoginData(e.ExternalLoginData),t.ReturnUrl(e.ReturnUrl)}).fail(t.handlevalidationerrors)},confirmexternalaccount:function(){var r=this;return 0!=this.errors().length?(this.errors.showAllMessages(),void 0):(e.confirmExternalAccount(r.DisplayName(),r.UserName(),r.Email(),r.ExternalLoginData()).then(function(){t.navigate(r.ReturnUrl())}).fail(r.handlevalidationerrors),void 0)}};return r.includeIn(c),c.errors=ko.validation.group(c),c});
define('viewmodels/account/externalloginfailure',["plugins/router"],function(e){return{convertRouteToHash:e.convertRouteToHash,activate:function(){ga("send","pageview",{page:window.location.href,title:document.title})}}});
define('viewmodels/account/login',["services/appsecurity","plugins/router","services/errorhandler"],function(e,t,r){var n=ko.observable().extend({required:!0}),a=ko.observable().extend({required:!0,minLength:6}),i=ko.observable(),o=ko.observable(),s=ko.observable(!1);ko.observable(!1);var l={convertRouteToHash:t.convertRouteToHash,username:n,password:a,rememberMe:i,returnUrl:o,isRedirect:s,appsecurity:e,activate:function(t){ga("send","pageview",{page:window.location.href,title:document.title});var r=t?t.redirectto:null;return"null"!=r&&this.isRedirect(!0),this.returnUrl(r),e.getExternalLogins().then(function(t){e.externalLogins(t)})},login:function(){if(0!=this.errors().length)return this.errors.showAllMessages(),void 0;var r=new e.credential(this.username(),this.password(),this.rememberMe()||!1),n=this;e.login(r).then(function(e){1==e.IsAuthenticated&&t.navigate(null!=n.returnUrl()?n.returnUrl():"account/manage")}).fail(n.handlevalidationerrors)},logout:function(){e.logout()},externalLogin:function(t,r){e.externalLogin(r.Provider,null!=this.returnUrl()?this.returnUrl():"account/manage")},socialIcon:function(e){var t="";switch(e.Provider.toLowerCase()){case"facebook":t="icon-facebook-sign";break;case"twitter":t="icon-twitter-sign";break;case"google":t="icon-google-plus-sign";break;case"microsoft":t="icon-envelope";break;default:t="icon-check-sign"}return t}};return r.includeIn(l),l.errors=ko.validation.group(l),l});
define('viewmodels/account/manage',["services/appsecurity","services/errorhandler","services/logger"],function(e,t,r){var n={hasAccount:ko.observable(),withLocalForm:{oldPassword:ko.observable().extend({required:!0,minLength:6}),newPassword:ko.observable().extend({required:!0,minLength:6}),confirmNewPassword:ko.observable().extend({required:!0,minLength:6})},withoutLocalForm:{newPassword:ko.observable().extend({required:!0,minLength:6}),confirmNewPassword:ko.observable().extend({required:!0,minLength:6})},externalAccounts:ko.observableArray(),showRemoveButton:ko.observable(),appsecurity:e,changePassword:function(){var t=this;return this.withLocalFormErrors.isValid()?(e.changePassword(this.withLocalForm.oldPassword(),this.withLocalForm.newPassword(),this.withLocalForm.confirmNewPassword()).then(function(){e.hasLocalAccount().then(function(e){t.hasAccount(e),t.withLocalForm.oldPassword(""),t.withLocalForm.newPassword(""),t.withLocalForm.confirmNewPassword(""),t.withLocalFormErrors.errors.showAllMessages(!1),r.logSuccess("Password changed succesfully",null,null,!0)})}).fail(t.handlevalidationerrors),void 0):(this.withLocalFormErrors.errors.showAllMessages(),void 0)},createLocalAccount:function(){var t=this;return this.withoutLocalFormErrors.isValid()?(e.createLocalAccount(this.withoutLocalForm.newPassword(),this.withoutLocalForm.confirmNewPassword()).then(function(){e.hasLocalAccount().then(function(n){t.hasAccount(n),t.withoutLocalForm.newPassword(""),t.withoutLocalForm.confirmNewPassword(""),r.logSuccess("Local account created succesfully",null,null,!0),e.externalAccounts().then(function(e){t.externalAccounts(e.ExternalLogins),t.showRemoveButton(e.ShowRemoveButton)}).fail(t.handlevalidationerrors)})}).fail(t.handlevalidationerrors),void 0):(this.withoutLocalFormErrors.errors.showAllMessages(),void 0)},removeExternalAccount:function(t,n){var a=this;e.dissasociate(n.Provider,n.ProviderUserId).then(function(t){r.logSuccess(t,null,null,!0),e.externalAccounts().then(function(e){a.externalAccounts(e.ExternalLogins),a.showRemoveButton(e.ShowRemoveButton)}).fail(a.handlevalidationerrors)}).fail(a.handlevalidationerrors)},activate:function(){var t=this;return ga("send","pageview",{page:window.location.href,title:document.title}),$.when(e.hasLocalAccount(),e.externalAccounts(),e.getExternalLogins()).then(function(r,n,a){t.hasAccount(r[0]),t.externalAccounts(n[0].ExternalLogins),t.showRemoveButton(n[0].ShowRemoveButton),e.externalLogins(a[0])}).fail(t.handlevalidationerrors)},externalLogin:function(t,r){e.externalLogin(r.Provider,"account/manage")},socialIcon:function(e){var t="";switch(e.Provider.toLowerCase()){case"facebook":t="icon-facebook-sign";break;case"twitter":t="icon-twitter-sign";break;case"google":t="icon-google-plus-sign";break;case"microsoft":t="icon-envelope";break;default:t="icon-check-sign"}return t}};return t.includeIn(n),n.withLocalFormErrors=ko.validatedObservable(n.withLocalForm),n.withoutLocalFormErrors=ko.validatedObservable(n.withoutLocalForm),n});
define('viewmodels/account/register',["services/appsecurity","plugins/router","services/errorhandler"],function(e,t,r){var n=ko.observable().extend({required:!0}),a=ko.observable().extend({required:!0,email:!0}),i=ko.observable().extend({required:!0,minLength:6}),o=ko.observable().extend({required:!0,minLength:6,equal:i}),s={username:n,email:a,password:i,confirmpassword:o,activate:function(){ga("send","pageview",{page:window.location.href,title:document.title})},register:function(){var t=this;return 0!=this.errors().length?(this.errors.showAllMessages(),void 0):(e.register(this.username(),this.email(),this.password(),this.confirmpassword(),"account/manage").fail(t.handlevalidationerrors),void 0)}};return r.includeIn(s),s.errors=ko.validation.group(s),s});
define('viewmodels/admin/panel',["services/unitofwork"],function(e){var t={userprofiles:ko.observableArray(),activate:function(){ga("send","pageview",{page:window.location.href,title:document.title})},attached:function(){var t=this,r=e.create();r.userprofiles.all().then(function(e){t.userprofiles(e)})}};return t});
define('viewmodels/header',["plugins/router","services/appsecurity","services/errorhandler"],function(e,t,r){var n={router:e,appsecurity:t,logout:function(){var e=this;t.logout().fail(e.handlevalidationerrors)}};return r.includeIn(n),n});
define('viewmodels/home/about',[],function(){return{activate:function(){ga("send","pageview",{page:window.location.href,title:document.title})}}});
define('viewmodels/home/articles',["services/unitofwork","services/errorhandler","plugins/router"],function(e,t,r){function n(e,t){var r=breeze.Predicate.create("isPublished","==",!0);if(e){var n=breeze.Predicate.create("title",breeze.FilterQueryOp.Contains,e).or(breeze.Predicate.create("description",breeze.FilterQueryOp.Contains,e));r=r.and(n)}return t&&(r=r.and(breeze.Predicate.create("categoryId","==",t))),r}var e=e.create(),a={convertRouteToHash:r.convertRouteToHash,search:ko.observable(""),selectedCategory:ko.observable(""),page:ko.observable(0),count:ko.observable(10),categories:ko.observableArray(),articles:ko.observableArray(),activate:function(){ga("send","pageview",{page:window.location.href,title:document.title})},attached:function(){var t=this;Stashy.OffCanvas("#articles .st-offcanvas",{closeOnClickOutside:!1}).layout(),$("#articles .st-offcanvas").animate({opacity:1},500);var r=e.publicarticles.find(n(t.search(),t.selectedCategory()),t.page(),t.count()).then(function(e){t.articles(e)}),a=e.categories.all().then(function(e){t.categories(e)});return Q.all([r,a]).fail(t.handleError)},evaluateKey:function(){return"keypress"==event.type&&13==event.keyCode&&this.searchArticles(!1),!0},changeSelectedCategory:function(e,t){t.selectedCategory(e.categoryId()),t.searchArticles(!1)},removeSelectedCategory:function(){this.selectedCategory(""),this.searchArticles(!1)},loadMoreArticles:function(){this.page(this.page()+1),this.searchArticles(!0)},searchArticles:function(t){var r=this;t||r.page(0),e.publicarticles.find(n(r.search(),r.selectedCategory()),r.page(),r.count()).then(function(e){t?ko.utils.arrayForEach(e,function(e){r.articles.push(e)}):r.articles(e),e.length<r.count()?$("#btn-loadmore").addClass("disabled"):$("#btn-loadmore").removeClass("disabled")})}};return t.includeIn(a),a});
define('viewmodels/home/index',["plugins/router"],function(e){function t(){$("#index #featured").animate({opacity:0},100),setTimeout(function(){$(document).trigger("debouncedresize"),$("#index #featured").animate({opacity:1},100)},500)}return{convertRouteToHash:e.convertRouteToHash,activate:function(){ga("send","pageview",{page:window.location.href,title:document.title}),t()},attached:function(){Stashy.Slider("#index #featured",{showControls:!1,showIndicators:!1,enableTouch:!0}).on(),t()},deactivate:function(){$("#index #featured").animate({opacity:0},100)}}});
define('viewmodels/notfound',["plugins/router"],function(e){return{convertRouteToHash:e.convertRouteToHash,activate:function(){ga("send","pageview",{page:window.location.href,title:document.title})}}});
define('viewmodels/shell',["plugins/router","services/appsecurity","services/errorhandler","services/entitymanagerprovider","model/modelBuilder"],function(e,t,r,n,a){n.modelBuilder=a.extendMetadata;var i={attached:function(){$(document).find("footer").show()},activate:function(){var r=this;return n.prepare().then(function(){return e.makeRelative({moduleId:"viewmodels"}),e.guardRoute=function(e,r){return r.config.authorize?t.user().IsAuthenticated&&t.isUserInRole(r.config.authorize)?!0:"/account/login?redirectto="+r.fragment:!0},e.map([{route:["","home/index"],moduleId:"home/index",title:"Home",nav:!0,hash:"#home/index"},{route:"home/articles",moduleId:"home/articles",title:"Articles",nav:!0,hash:"#home/articles"},{route:"home/about",moduleId:"home/about",title:"About",nav:!0,hash:"#home/about"},{route:"notfound",moduleId:"notfound",title:"Not found",nav:!1},{route:"admin/panel",moduleId:"admin/panel",title:"Admin Panel",nav:!1,hash:"#admin/panel",authorize:["Administrator"]},{route:"account/login",moduleId:"account/login",title:"Login",nav:!1,hash:"#account/login"},{route:"account/externalloginconfirmation",moduleId:"account/externalloginconfirmation",title:"External login confirmation",nav:!1,hash:"#account/externalloginconfirmation"},{route:"account/externalloginfailure",moduleId:"account/externalloginfailure",title:"External login failure",nav:!1,hash:"#account/externalloginfailure"},{route:"account/register",moduleId:"account/register",title:"Register",nav:!1,hash:"#account/register"},{route:"account/manage",moduleId:"account/manage",title:"Manage account",nav:!1,hash:"#account/manage",authorize:["User","Administrator"]},{route:"user/dashboard",moduleId:"user/dashboard",title:"Dashboard",nav:!1,hash:"#user/dashboard",authorize:["User"]},{route:":createdby/:categorycode/:articlecode",moduleId:"user/article",title:"Article",nav:!1}]).buildNavigationModel().mapUnknownRoutes("notfound","notfound").activate({pushState:!0})}).fail(r.handlevalidationerrors)}};return r.includeIn(i),i});
define('viewmodels/user/article',["services/unitofwork","plugins/router"],function(e,t){var r,n={article:ko.observable(),activate:function(n,a,i){var o=this;r=n+"/"+a+"/"+i;var s=e.get(r),l=s.value();return ga("send","pageview",{page:window.location.href,title:document.title}),l.publicarticles.find(breeze.Predicate.create("urlCodeReference","==",i).and("category.urlCodeReference","==",a).and("createdBy","==",n),0,1).then(function(e){void 0!=e[0]?o.article(e[0]):t.navigate("notfound")})},deactivate:function(){e.get(r).release()}};return n});
define('viewmodels/user/dashboard',["services/unitofwork","services/errorhandler","services/logger","services/utils"],function(e,t,r,n){function a(e,t){for(var r=0;r<t().length;r++)if(e==t()[r].name())return t()[r]}function i(e){$("#tags").tagsInput({onAddTag:function(t){e().addTag(t)},onRemoveTag:function(t){e().deleteTag(a(t,e().tags))},defaultText:"New tag"})}var e=e.create(),o={categories:ko.observableArray(),selectedArticle:ko.observable(),articles:ko.observableArray(),updating:ko.observable(!1),preview:ko.observable(!1),activate:function(){ga("send","pageview",{page:window.location.href,title:document.title})},attached:function(){var t=this;Stashy.FocalPoint("#dashboard img").on(),$("#dashboard #edited-article").on("hide.bs.modal",function(){t.selectedArticle().entityAspect.hasValidationErrors&&(ko.validation.group(t.selectedArticle()),t.selectedArticle().errors.showAllMessages()),t.selectedArticle().unsavedChanges(t.selectedArticle().entityAspect.entityState.isAddedModifiedOrDeleted())}),Stashy.ShowMeMore("#dashboard-articles .row",{linkClass:"btn btn-primary",linkText:"Show more articles",howMany:4}).on(),$("#dashboard #edited-article").on("shown.bs.modal",function(){$("#dashboard #edited-article .zen-mode").zenForm({trigger:"#dashboard #edited-article .go-zen"}),$("#dashboard #edited-article .zen-mode").keyup()}),$("#dashboard #edited-article").on("zf-destroyed",function(){$("#dashboard #edited-article .zen-mode").trigger("change")});var r=e.privatearticles.all().then(function(e){t.articles(e)}),n=e.categories.all().then(function(e){t.categories(e)});Q.all([r,n]).fail(t.handleError)},newArticle:function(){var t=this,r=e.privatearticles.create({categoryId:this.categories()[0].categoryId()});this.articles.unshift(r),this.selectedArticle(r),i(t.selectedArticle),this.updating(!1),$("#edited-article").modal("show")},editArticle:function(e){var t=this;this.selectedArticle(e),i(t.selectedArticle),this.updating(!0),$("#edited-article").modal("show")},saveArticles:function(){var t=this;return e.hasChanges()?(e.commit().then(function(){r.logSuccess("Article saved succesfully",null,null,!0),ko.utils.arrayForEach(t.articles(),function(e){e.unsavedChanges(e.entityAspect.entityState.isAddedModifiedOrDeleted())})}).fail(this.handleError),!0):!0},deleteArticle:function(t,n,a){var i=this;ko.utils.arrayForEach(t.tags(),function(){t.deleteTag(t.tags()[0])}),e.privatearticles.delete(t),e.commit().then(function(){n.articles.remove(t),r.logSuccess("Article removed succesfully",null,null,!0),a&&$("#edited-article").modal("hide")}).fail(i.handleError)},closeModal:function(){$("#edited-article").modal("hide")},changePreview:function(e,t){t.preview()?t.preview(!1):t.preview(!0)},convertMarkdown:function(e){e.html(marked(e.markdown()))},utils:n};return t.includeIn(o),o});
define('text',{load: function(id){throw new Error("Dynamic load not allowed: " + id);}});
define('text!views/account/externalloginconfirmation.html',[],function () { return '<div id="externalloginconfirmation">\r\n    <div class="container">\r\n        <div class="page-header">\r\n            <h1 class="text-center">External login confirmation   <small>confirm your internal user name and mail</small></h1>\r\n        </div>\r\n        <div class="row">\r\n            <div class="col-lg-offset-2 col-lg-7">\r\n                <div class="alert alert-success">\r\n                    <button type="button" class="close" data-dismiss="alert">x</button>\r\n                    <strong>You\'ve successfully</strong> authenticated with <span data-bind="text: DisplayName"></span>.\r\n                    Please enter a user name for this site below and click the Confirm button to finish\r\n                    logging in.\r\n                </div>\r\n                <form data-bind="submit: confirmexternalaccount">            \r\n                    <div class="page-header">\r\n                        <h4>Associate your <span data-bind="text: DisplayName"></span> account</h4>\r\n                    </div>    \r\n                    <div class="form-group" data-bind="validationElement: UserName">\r\n                        <label class="control-label" for="UserName">User name</label>        \r\n                        <input class="form-control" type="text" data-bind="value: UserName" placeholder="User name">        \r\n                    </div>\r\n                    <div class="form-group" data-bind="validationElement: Email">\r\n                        <label class="control-label" for="Email">Email</label>    \r\n                        <input class="form-control" type="text" data-bind="value: Email" placeholder="Email">    \r\n                    </div>\r\n                    <div class="panel-footer">\r\n                        <button type="submit" class="btn btn-primary" >Confirm account</button>    \r\n                    </div>\r\n                </form>\r\n            </div>\r\n        </div>\r\n    </div>\r\n</div>';});

define('text!views/account/externalloginfailure.html',[],function () { return '<div id="externalloginfailure">\r\n    <div class="container">\r\n        <div class="page-header">\r\n            <h1>External login failure</h1>\r\n        </div>\r\n        <div class="alert alert-danger">\r\n            <button type="button" class="close" data-dismiss="alert">x</button>\r\n            <strong>Could not authenticate </strong>using your credentials. Try later and if the problem persist <a data-bind="attr: { href: convertRouteToHash(\'/home/about\') }">contact with us</a>\r\n        </div>\r\n    </div>\r\n</div>';});

define('text!views/account/login.html',[],function () { return '<div id="login">\r\n    <div class="container">\r\n        <div class="page-header">\r\n            <h1>Login to your account   <small>use your site credentials or any of the external providers allowed</small></h1>\r\n        </div>\r\n        <div class="row" data-bind="visible: !appsecurity.user().IsAuthenticated">\r\n            <div class="col-lg-6">\r\n                <form class="form-horizontal">\r\n                    <div class="page-header">\r\n                        <h4>Sign in with your credentials</h4>\r\n                    </div>\r\n                    <div class="form-group" data-bind="validationElement: username">\r\n                       <label class="control-label col-lg-4" for="username">Username</label>\r\n                        <div class="col-lg-8">\r\n                            <input class="form-control" type="text"  data-bind="value: username" placeholder="User name">                       \r\n                        </div>\r\n                    </div>\r\n                    <div class="form-group" data-bind="validationElement: password">\r\n                        <label class="control-label col-lg-4" for="email">Password</label>\r\n                        <div class="col-lg-8">\r\n                            <input class="form-control" type="password"  data-bind="value: password" placeholder="Password">                        \r\n                        </div>\r\n                    </div>  \r\n                    <div class="checkbox col-lg-offset-4">\r\n                        <label class="checkbox">\r\n                            <input type="checkbox" data-bind="value: rememberMe">Remember me\r\n                        </label>                      \r\n                    </div>                                                                                                     \r\n                    <div class="col-lg-offset-4 mart2">\r\n                        <button type="submit" class="btn btn-primary" data-bind="click: login">Sign in</button>\r\n                        <button type="reset" class="btn btn-default">Reset</button>                        \r\n                        <p class="mart5"> <a href="#" class="btn btn-link" data-bind="attr: { href: convertRouteToHash(\'/account/register\') }">Register</a>if don\'t have and account?</p>\r\n                    </div> \r\n                </form>                      \r\n            </div>\r\n    \r\n            <div class="col-offset-1 col-lg-5">\r\n                <div class="page-header">\r\n                    <h4>... or you can sign in using another service</h4>\r\n                </div>\r\n                <div class="list-group" data-bind="foreach: appsecurity.externalLogins">                        \r\n                    <a class="list-group-item lead" href="#"  data-bind="click: function (data, event) { $parent.externalLogin($parent, data, event) }, attr: { \'data-provider\': Provider }">\r\n                        <i data-bind="css: $parent.socialIcon($data)"></i>\r\n                        <span data-bind="text: ProviderDisplayName"></span>\r\n                    </a>\r\n                </div>\r\n            </div>    \r\n        </div>\r\n  \r\n        <div class="jumbotron" data-bind="visible: appsecurity.user().IsAuthenticated && !isRedirect()">\r\n            <h2>You are actually logged in</h2>\r\n            <a class="btn btn-primary" data-bind="click : logout">Logout</a>\r\n        </div>\r\n\r\n        <div class="jumbotron" data-bind="visible: appsecurity.user().IsAuthenticated && isRedirect()">\r\n            <h2>You are actually logged in but cannot access this route with your current permissions</h2>\r\n            <p class="lead">Sign out and enter again the credentials with the correct permissions</p>\r\n            <a class="btn btn-primary" data-bind="click: logout">Logout</a>\r\n        </div>\r\n\r\n    </div>\r\n</div>';});

define('text!views/account/manage.html',[],function () { return '<div id="manage">\r\n    <div class="container">\r\n        <div class="page-header">\r\n            <h1>Manage your account   <small>change passwords and manage your external accounts</small></h1>\r\n        </div>\r\n        <div class="row">\r\n            <div class="col-lg-6">                \r\n                <form data-bind="if: hasAccount, submit: changePassword" class="form-horizontal">\r\n                    <div class="page-header">\r\n                        <h4>Change password</h4>\r\n                    </div>\r\n                    <div class="form-group" data-bind="validationElement: withLocalForm.oldPassword">\r\n                        <label class="control-label col-lg-4" for="oldpassword">Old Password</label>\r\n                        <div class="col-lg-8">\r\n                            <input class="form-control" type="password"  data-bind="value: withLocalForm.oldPassword" placeholder="Old Password">\r\n                        </div>                        \r\n                    </div>\r\n                    <div class="form-group" data-bind="validationElement: withLocalForm.newPassword">\r\n                        <label class="control-label col-lg-4" for="newPassword">New Password</label>        \r\n                        <div class="col-lg-8">           \r\n                            <input class="form-control" type="password"  data-bind="value: withLocalForm.newPassword" placeholder="New Password">                                        \r\n                        </div>\r\n                    </div>\r\n                    <div class="form-group" data-bind="validationElement: withLocalForm.confirmNewPassword">\r\n                           <label class="control-label col-lg-4" for="confirmNewPassword">Confirm new Password</label>\r\n                            <div class="col-lg-8">\r\n                                <input class="form-control" type="password"  data-bind="value: withLocalForm.confirmNewPassword" placeholder="Confirm New Password">                                           \r\n                            </div>\r\n                    </div>\r\n                    <div class="form-group">\r\n                        <div class="col-lg-offset-4">\r\n                            <button type="submit" class="btn btn-primary">Change password</button>\r\n                            <button type="reset" class="btn btn-default">Reset</button>\r\n                        </div>\r\n                    </div>                   \r\n               </form>  \r\n               <form data-bind="if: !hasAccount(), submit: createLocalAccount" class="form-horizontal col-lg-offset-1">\r\n                    <fieldset>\r\n                        <legend>Create local account</legend>\r\n                        <div class="form-group" data-bind="validationElement: withoutLocalForm.newPassword">\r\n                            <label class="control-label col-lg-4" for="newPassword">New Password</label> \r\n                            <div class="col-lg-8">                      \r\n                                <input class="form-control" type="password"  data-bind="value: withoutLocalForm.newPassword" placeholder="New Password">                                               \r\n                            </div>\r\n                        </div>  \r\n                        <div class="form-group" data-bind="validationElement: withoutLocalForm.confirmNewPassword">\r\n                            <label class="control-label col-lg-4" for="confirmNewPassword">Confirm new Password</label>\r\n                            <div class="col-lg-8">\r\n                                <input class="form-control" type="password"  data-bind="value: withoutLocalForm.confirmNewPassword" placeholder="Confirm New Password">                                           \r\n                            </div>\r\n                        </div>         \r\n                        <div class="form-group">\r\n                            <div class="col-lg-offset-4">\r\n                                <button type="submit" class="btn btn-primary">Create local account</button>\r\n                                <button type="reset" class="btn btn-default">Reset</button>                \r\n                            </div>        \r\n                        </div>                                             \r\n                    </fieldset>\r\n               </form>  \r\n            </div>\r\n\r\n            <div class="col-lg-offset-1 col-lg-5">\r\n                <div data-bind="visible: externalAccounts().length > 0">\r\n                    <div class="page-header">\r\n                        <h4>You have registered logins with the following providers</h4>\r\n                    </div>\r\n                </div>\r\n                <div data-bind="foreach: externalAccounts">\r\n                    <div class="row">\r\n                        <div class="col-xs-4">\r\n                            <p class="lead" data-bind="text: ProviderDisplayName" style="border:none"></p>\r\n                        </div>\r\n                        <div class="col-xs-8" data-bind="if: $parent.showRemoveButton">\r\n                            <a class="btn btn-danger" href="#" data-bind="click: function (data, event) { $parent.removeExternalAccount($parent, data, event); }, text: \'Remove\'"></a>\r\n                        </div>\r\n                    </div>                \r\n                </div>        \r\n                <div class="page-header">\r\n                    <h4>Associate more external accounts to this one</h4>\r\n                </div>                \r\n                <div class="list-group" data-bind="foreach: appsecurity.externalLogins">                        \r\n                    <a class="list-group-item lead" href="#"  data-bind="click: function (data, event) { $parent.externalLogin($parent, data, event) }, attr: { \'data-provider\': Provider }">\r\n                        <i data-bind="css: $parent.socialIcon($data)"></i>\r\n                        <span data-bind="text: ProviderDisplayName"></span>\r\n                    </a>\r\n                </div>\r\n                <hr />\r\n            </div>\r\n        </div>\r\n    </div>\r\n</div>';});

define('text!views/account/register.html',[],function () { return '<div id="register">\r\n    <div class="container">\r\n        <div class="page-header">\r\n            <h1 class="text-center">Register now   <small>create a new account in this site</small></h1>\r\n        </div>\r\n        <div class="row">\r\n            <div class="col-lg-offset-3 col-lg-6">        \r\n                <form data-bind="submit : register" class="form-horizontal">\r\n                    <div class="form-group" data-bind="validationElement: username">\r\n                         <label class="control-label col-lg-4" for="username">Username</label>                        \r\n                        <div class="col-lg-8">\r\n                            <input class="form-control" type="text"  data-bind="value: username" placeholder="User name">      \r\n                        </div>\r\n                    </div>\r\n                    <div class="form-group" data-bind="validationElement: email">\r\n                         <label class="control-label col-lg-4" for="username">Email</label>                     \r\n                        <div class="col-lg-8">\r\n                            <input class="form-control" type="text"  data-bind="value: email" placeholder="Email"> \r\n                        </div>\r\n                    </div>                   \r\n                    <div class="form-group" data-bind="validationElement: password">\r\n                         <label class="control-label col-lg-4" for="email">Password</label>\r\n                        <div class="col-lg-8">\r\n                            <input class="form-control" type="password"  data-bind="value: password" placeholder="Password">  \r\n                        </div>\r\n                    </div>  \r\n                    <div class="form-group" data-bind="validationElement: confirmpassword">\r\n                         <label class="control-label col-lg-4" for="email">Confirm Password</label>\r\n                        <div class="col-lg-8">\r\n                            <input class="form-control" type="password"  data-bind="value: confirmpassword" placeholder="Confirm Password">  \r\n                        </div>\r\n                    </div>  \r\n                    <div class="col-lg-offset-4">\r\n                        <button type="submit" class="btn btn-primary">Register</button>\r\n                        <button type="reset" class="btn btn-default">Reset</button>\r\n                    </div>    \r\n                </form>                      \r\n            </div>          \r\n        </div>\r\n    </div>\r\n </div>';});

define('text!views/admin/panel.html',[],function () { return '<div id="panel">\r\n    <div class="container">\r\n        <div class="page-header">\r\n            <h1>Admin Panel   <small>supersecret information :)</small></h1>\r\n        </div>\r\n        <h4>Check the list of the registered users on this site</h4>\r\n        <div class="row mart5" data-bind="foreach : userprofiles">\r\n            <div class="col-xs-12 col-sm-6 col-md-4 col-lg-3">\r\n                <div class="row">\r\n                    <div class="col-xs-3">\r\n                        <a class="thumbnail">\r\n                            <img src="/Content/icons/icon_user.png"/>\r\n                        </a>                        \r\n                    </div>\r\n                    <div class="col-xs-9 h-vcenter-parent">\r\n                        <div class="h-vcenter-child">\r\n                            <h4 data-bind="text: userName"></h4>                        \r\n                        </div>                        \r\n                    </div>\r\n                </div>\r\n            </div>\r\n        </div>\t       \r\n    </div>\r\n</div>\r\n';});

define('text!views/header.html',[],function () { return '<nav class="navbar navbar-inverse navbar-fixed-top" role="navigation">\r\n    <div class="navbar-header">        \r\n        <button type="button" class="navbar-toggle"  data-toggle="collapse" data-target=".navbar-main-collapse">\r\n            <span class="icon-bar"></span>\r\n            <span class="icon-bar"></span>\r\n            <span class="icon-bar"></span>\r\n        </button>              \r\n        <a data-bind="attr: { href: router.convertRouteToHash(\'/\' + router.navigationModel()[0].hash) }" class="navbar-brand">DurandalAuth</a>\r\n    </div>\r\n    <div class="collapse navbar-collapse navbar-main-collapse" style="height: 0px;">\r\n        <ul class="nav navbar-nav" data-bind="foreach: router.navigationModel">\r\n            <li data-bind="css: { active: isActive }">\r\n               <a data-bind="attr: { href: $parent.router.convertRouteToHash(\'/\' + hash) }, text: title"></a>\r\n            </li>\r\n        </ul>\r\n        <ul class="nav navbar-nav navbar-right" data-bind="if: !appsecurity.user().IsAuthenticated">\r\n            <li>                    \r\n                <a data-bind="attr: { href: router.convertRouteToHash(\'/account/login\') }"><i class="icon-user"></i>&nbsp; Login</a>\r\n            </li>\r\n        </ul>\r\n        \r\n        <ul class="nav navbar-nav navbar-right" data-bind="if: appsecurity.user().IsAuthenticated">\r\n            <li class="dropdown">\r\n                <a href="#" class="dropdown-toggle" data-toggle="dropdown">\r\n                    <i class="icon-user"></i>&nbsp; Hi <span data-bind="text: appsecurity.user().UserName"></span>\r\n                    <b class="caret"></b>\r\n               </a>                                \r\n               <ul class="dropdown-menu">\r\n                    <li><a data-bind="attr: { href: router.convertRouteToHash(\'/account/manage\') }">Manage your account</a></li>\r\n                    <li data-bind="visible: appsecurity.isUserInRole([\'User\'])"><a data-bind="    attr: { href: router.convertRouteToHash(\'/user/dashboard\') }">Dashboard</a></li>\r\n                    <li data-bind="visible: appsecurity.isUserInRole([\'Administrator\'])" class="divider"></li>\r\n                    <li data-bind="if: appsecurity.isUserInRole([\'Administrator\'])"><a data-bind="    attr: { href: router.convertRouteToHash(\'/admin/panel\') }">Admin Panel</a></li>\r\n                    <li class="divider"></li>\r\n                    <li><a href="#" data-bind="click: logout">Logout</a></li>\r\n                </ul>\r\n            </li>          \r\n        </ul>                          \r\n    </div>              \r\n</nav>';});

define('text!views/home/about.html',[],function () { return '<div id="about">\r\n    <div class="row">\r\n        <div class="col-lg-6">\r\n            <div class="about-content strawberry">\r\n                <h1><i class="icon-user"></i>    Who am I?</h1>\r\n                <p class="lead">My name is Yago and I am a developer who \r\n\t\t\t\tis passionate about web design and programming.</p>     \r\n            </div>                                                \r\n            <div class="about-content strawberry" style="margin-top:-5px;">\r\n                <h1><i class="icon-eye-open"></i>    What I like to do?</h1>\r\n                <p class="lead">I like to learn and explore new technologies and development environments. I also like to take a look at new and amazing projects to see how they evolve.</p>                      \r\n            </div>                        \r\n        </div>\r\n        <div class="col-lg-6">\r\n            <div class="about-content sky">\r\n                <h1><i class="icon-comments"></i>    How can you contact me?</h1>\r\n                <ul class="unstyled">\r\n                    <li><a href="#" onclick="window.open(\'https://github.com/yagopv\', \'_blank\')"><i class="icon-github"></i>    Github</a></li>\r\n                    <li><a href="#" onclick="window.open(\'https://twitter.com/yperezva\', \'_blank\')"><i class="icon-twitter-sign"></i>    Twitter</a></li>\r\n                    <li><a href="#" onclick="window.open(\'https://www.facebook.com/yago.perezvazquez\', \'_blank\')"><i class="icon-facebook-sign"></i>    Facebook</a></li>           \r\n                    <li><a href="#" onclick="window.open(\'http://es.linkedin.com/pub/yago-p%C3%A9rez-v%C3%A1zquez/45/453/381\', \'_blank\')"><i class="icon-linkedin-sign"></i>    LinkedIn</a></li>\r\n                </ul>                                            \r\n            </div>        \r\n            <div class="about-content sky" style="margin-top:-5px;">\r\n                <h1><i class="icon-cloud"></i>    Where I am?</h1>\r\n                <p class="lead">In a galaxy far, far away...</p>                \r\n            </div>                    \r\n        </div>            \r\n    </div>\r\n</div>';});

define('text!views/home/articles.html',[],function () { return '<div id="articles">\r\n    <div class="st-offcanvas">\r\n        <div class="st-offcanvas-menu">\r\n            <div class="input-group mart5">\r\n                <input type="text" class="form-control" data-bind="value: search, event: { \'change\': function () { searchArticles(false); }, \'keypress\': evaluateKey }" placeholder="Search for articles">\r\n                <span class="input-group-btn">\r\n                    <button class="btn btn-default" data-bind="click: function () { searchArticles(false); }" type="button"><i class="icon-search"></i></button>\r\n                </span>\r\n            </div>\r\n            <div class="panel panel-default mart5">\r\n                <div class="panel-heading">Select any Category</div>\r\n                <div class="list-group">\r\n                    <a href="#" class="list-group-item" data-bind="text: \'All\', click: removeSelectedCategory"></a>\r\n                    <!-- ko  foreach : categories -->\r\n                        <a href="#" class="list-group-item" data-bind="text: name, click: function () { $parent.changeSelectedCategory($data, $parent) } "></a>\r\n                    <!-- /ko -->                    \r\n                </div>\r\n            </div>\r\n        </div>\r\n        <div class="st-offcanvas-main">\r\n            <div class="row offcanvas-buttons">\r\n                <a href="#" class="showmenubutton"><i class="icon-th"></i></a>\r\n            </div>\r\n\r\n            <div data-bind="if: articles().length === 0" class="mart5">\r\n                <h1>No articles found</h1>\r\n                <p class="lead">Change filter criteria to find articles</p>\r\n            </div>\r\n\r\n            <div data-bind="if: articles().length > 0" class="mart5">\r\n                <!-- Articles List -->\r\n\r\n                <div data-bind="foreach: articles">\r\n                    <div class="row mart2">\r\n                        <div class="hidden-xs col-sm-3 col-md-2 col-lg-2">\r\n                            <div class="st-image">\r\n                                <div class="st-image-container">\r\n                                    <a href="#" class="thumbnail">\r\n                                        <img data-bind="attr: { src: imageUrl }" />\r\n                                    </a>\r\n                                </div>\r\n                            </div>\r\n                        </div>\r\n                        <div class="col-xs-12 col-sm-9 col-md-10 col-lg-10">\r\n                            <h2 class="mart0" data-bind="text: title"></h2>\r\n                            <div class="mart2">\r\n                                <span class="label label-info" data-bind="text: formattedCreatedDate"></span>\r\n                                <span class="label label-info" data-bind="text: createdBy"></span>\r\n                            </div>\r\n                            <p class="mart2" data-bind="text: description"></p>\r\n                            <div class="mart2">\r\n                                <a class="btn btn-primary" data-bind="attr: { href: $parent.convertRouteToHash(\'/\' + createdBy() + \'/\' + category().urlCodeReference() + \'/\' + urlCodeReference()).toLowerCase(), title : title }"><i class="icon-eye"></i>View article</a>\r\n                            </div>\r\n                        </div>\r\n                    </div>\r\n                    <hr class="mart5" />\r\n                </div>\r\n\r\n                <!-- Articles List End -->\r\n                <a href="#" id="btn-loadmore" class="btn btn-primary mart2" data-bind="click: loadMoreArticles">Load more articles</a>\r\n            </div>\r\n            <hr class="mart2" />\r\n        </div>\r\n    </div>\r\n</div>';});

define('text!views/home/index.html',[],function () { return '<div id="index">\r\n\t<div id="featured" class="st-slider">\r\n\t\t<ul class="jumbotron st-slider-panes">\r\n\t\t\t<li>\r\n\t\t\t\t<div class="st-slider-content">\r\n\t\t\t\t\t<div class="row">\r\n\t\t\t\t\t\t<div class="col-sm-offset-1 col-sm-10">\r\n\t\t\t\t\t\t\t<div class="hidden-xs col-sm-3 col-md-2 col-lg-2">\r\n\t\t\t\t\t\t\t\t<a class="thumbnail" href="#">\r\n\t\t\t\t\t\t\t\t\t<img src="/Content/icons/icon_lock.png" alt="Durandal!!" />\r\n\t\t\t\t\t\t\t\t</a>\r\n\t\t\t\t\t\t\t</div>\r\n\t\t\t\t\t\t\t<div class="col-xs-12 col-sm-9 col-md-10 col-lg-10">\r\n\t\t\t\t\t\t\t\t<h1 class="mart0">Welcome to the DurandalAuth sample project !!</h1>\r\n\t\t\t\t\t\t\t\t<p class="mart2 prewrap">This template provides a way to authenticate users using Durandal and FormsAuthentication with\tan ASP SimpleMembership Provider.</p>\r\n\t\t\t\t\t\t\t</div>\r\n\t\t\t\t\t\t</div>\r\n\t\t\t\t\t</div>\r\n\t\t\t\t</div>\r\n\t\t\t</li>\r\n\t\t\t<li>\r\n\t\t\t\t<div class="st-slider-content">\r\n\t\t\t\t\t<div class="row">\r\n\t\t\t\t\t\t<div class="col-sm-offset-1 col-sm-10">\r\n\t\t\t\t\t\t\t<div class="hidden-xs col-sm-3 col-md-2 col-lg-2">\r\n\t\t\t\t\t\t\t\t<a class="thumbnail" href="#">\r\n\t\t\t\t\t\t\t\t\t<img src="/Content/icons/icon_data.png" alt="Breeze!!" />\r\n\t\t\t\t\t\t\t\t</a>\r\n\t\t\t\t\t\t\t</div>\r\n\t\t\t\t\t\t\t<div class="col-xs-12 col-sm-9 col-md-10 col-lg-10">\r\n\t\t\t\t\t\t\t\t<h1 class="mart0">Breeze for data management</h1>\r\n\t\t\t\t\t\t\t\t<p class="mart2 prewrap">Client-side data management uses the excellent Breeze JS framework.</p>\r\n\t\t\t\t\t\t\t</div>\r\n\t\t\t\t\t\t</div>\r\n\t\t\t\t\t</div>\r\n\t\t\t\t</div>\r\n\t\t\t</li>\r\n\t\t\t<li>\r\n\t\t\t\t<div class="st-slider-content">\r\n\t\t\t\t\t<div class="row">\r\n\t\t\t\t\t\t<div class="col-sm-offset-1 col-sm-10">\r\n\t\t\t\t\t\t\t<div class="hidden-xs col-sm-3 col-md-2 col-lg-2">\r\n\t\t\t\t\t\t\t\t<a class="thumbnail" href="#">\r\n\t\t\t\t\t\t\t\t\t<img src="/Content/icons/icon_cloud.png" alt="ASP MVC and Web API" />\r\n\t\t\t\t\t\t\t\t</a>\r\n\t\t\t\t\t\t\t</div>\r\n\t\t\t\t\t\t\t<div class="col-xs-12 col-sm-9 col-md-10 col-lg-10">\r\n\t\t\t\t\t\t\t\t<h1 class="mart0">ASP MVC and Web API</h1>\r\n\t\t\t\t\t\t\t\t<p class="mart2 prewrap">ASP MVC and Web API are used on the server-side.</p>\r\n\t\t\t\t\t\t\t</div>\r\n\t\t\t\t\t\t</div>\r\n\t\t\t\t\t</div>\r\n\t\t\t\t</div>\r\n\t\t\t</li>\r\n\t\t\t<li>\r\n\t\t\t\t<div class="st-slider-content">\r\n\t\t\t\t\t<div class="row">\r\n\t\t\t\t\t\t<div class="col-sm-offset-1 col-sm-10">\r\n\t\t\t\t\t\t\t<div class="hidden-xs col-sm-3 col-md-2 col-lg-2">\r\n\t\t\t\t\t\t\t\t<a class="thumbnail" href="#">\r\n\t\t\t\t\t\t\t\t\t<img src="/Content/icons/icon_library.png" alt="Patterns!!" />\r\n\t\t\t\t\t\t\t\t</a>                                        \r\n\t\t\t\t\t\t\t</div>\r\n\t\t\t\t\t\t\t<div class="col-xs-12 col-sm-9 col-md-10 col-lg-10">\r\n\t\t\t\t\t\t\t\t<h1 class="mart0">Unit of Work and Repositories</h1>\r\n\t\t\t\t\t\t\t\t<p class="mart2 prewrap">You will find an implementation of this pattern on both the server (Entity Framework) and the client (Breeze).</p>\r\n\t\t\t\t\t\t\t</div>\r\n\t\t\t\t\t\t</div>\r\n\t\t\t\t\t</div>\r\n\t\t\t\t</div>\r\n\t\t\t</li>\r\n\t\t\t<li>\r\n\t\t\t\t<div class="st-slider-content">\r\n\t\t\t\t\t<div class="row">\r\n\t\t\t\t\t\t<div class="col-sm-offset-1 col-sm-10">\r\n\t\t\t\t\t\t\t<div class="hidden-xs col-sm-3 col-md-2 col-lg-2">\r\n\t\t\t\t\t\t\t\t<a class="thumbnail" href="#">\r\n\t\t\t\t\t\t\t\t\t<img src="/Content/icons/icon_seo.png" alt="SEO ready!!" />\r\n\t\t\t\t\t\t\t\t</a>                                        \r\n\t\t\t\t\t\t\t</div>\r\n\t\t\t\t\t\t\t<div class="col-xs-12 col-sm-9 col-md-10 col-lg-10">\r\n\t\t\t\t\t\t\t\t<h1 class="mart0">SEO Optimization</h1>\r\n\t\t\t\t\t\t\t\t<p class="mart2 prewrap">The template is ready to be SEO crawlable using a <a href="#" onclick="window.open(\'https://github.com/yagopv/azurecrawler\', \'_blank\')">headless browser</a></p>\r\n\t\t\t\t\t\t\t</div>\r\n\t\t\t\t\t\t</div>\r\n\t\t\t\t\t</div>\r\n\t\t\t\t</div>\r\n\t\t\t</li>\r\n\t\t\t<li>\r\n\t\t\t\t<div class="st-slider-content">\r\n\t\t\t\t\t<div class="row">\r\n\t\t\t\t\t\t<div class="col-sm-offset-1 col-sm-10">\r\n\t\t\t\t\t\t\t<div class="hidden-xs col-sm-3 col-md-2 col-lg-2">\r\n\t\t\t\t\t\t\t\t<a class="thumbnail" href="#">\r\n\t\t\t\t\t\t\t\t\t<img src="/Content/icons/icon_angles.png" alt="Bootstrap!!" />\r\n\t\t\t\t\t\t\t\t</a>                                        \r\n\t\t\t\t\t\t\t</div>\r\n\t\t\t\t\t\t\t<div class="col-xs-12 col-sm-9 col-md-10 col-lg-10">\r\n\t\t\t\t\t\t\t\t<h1 class="mart0">... and of course</h1>\r\n\t\t\t\t\t\t\t\t<p class="mart2 prewrap">My favorite tool ... Bootstrap for styling this site.</p>\r\n\t\t\t\t\t\t\t</div>\r\n\t\t\t\t\t\t</div>\r\n\t\t\t\t\t</div>\r\n\t\t\t\t</div>\r\n\t\t\t</li>\r\n\t\t</ul>\r\n\t</div>\r\n\t<div class="container">\r\n\t\t<div class="row mart5">\r\n\t\t\t<div class="col-lg-4 text-center">                \r\n\t\t\t\t<img src="/Content/icons/icon_question.png" alt="Why this project?" width="150" />\r\n\t\t\t\t<h3>Why this project?</h3>\r\n\t\t\t\t<p>Because I couldn\'t find any proper way of working with this technology stack and this kind of authentication ... so \r\n\t\t\t\tI tried to write it myself.</p>\r\n\t\t\t</div>\r\n\t\t\t<div class="col-lg-4 text-center">\r\n\t\t\t\t<img src="/Content/icons/icon_social.png" alt="Collaborate" width="150" />\r\n\t\t\t\t<h3>Collaborate</h3>\r\n\t\t\t\t<p>If you find bugs or want to improve the sample project template, feel free to contact me, create \r\n\t\t\t\ta pull request, or \r\n\t\t\t\twhatever you want.</p>\r\n\t\t\t</div>\r\n\t\t\t<div class="col-lg-4 text-center">\r\n\t\t\t\t<img src="/Content/icons/icon_project.png" alt="Project" width="150" />                \r\n\t\t\t\t<h3>Visit the project site ...</h3>\r\n\t\t\t\t<p>... <a href="#" onclick="window.open(\'https://github.com/yagopv/durandalauth\', \'_blank\')"> on Github</a> and check the code if you want.</p>\r\n\t\t\t</div>\r\n\t\t</div>\r\n\t\t<div class="row mart5">\r\n\t\t\t<div class="col-lg-12">\r\n\t\t\t\t<div class="page-header">\r\n\t\t\t\t\t<h2>How is this site working?</h2>\r\n\t\t\t\t</div>            \r\n\t\t\t\t<p>This site simulates a community-managed article repository. People with accounts can write articles in their dashboards and make them public on the web.</p>\r\n\t\t\t\t<p>The main objective of this sample application is to provide a way to authenticate and authorize users similar to the default ASP MVC 4 Internet template. You will find Forms and oAuth authentication built-in with the main social providers among another useful features.</p>\r\n\t\t\t\t<p>I decided to leverage the first template I created to build a more complete application in order to show what Breeze JS can do for you and how to protect saving changes on server.</p>            \r\n\t\t\t\t<hr />\r\n\t\t\t\t<p>The first thing you should do is create a new account using the <a href="#" data-bind="attr: { href: convertRouteToHash(\'account/login\') }">membership system or the oAuth providers</a>.</p>\r\n\t\t\t\t<p>After registration, a <span class="label label-info">User</span> \r\n\t\t\t\trole will be assigned to you that will permit access to the <a href="#" data-bind="attr: { href: convertRouteToHash(\'user/dashboard\') }">user dashboard</a>. Once there, you can start writing articles.</p>\r\n\t\t\t\t<p>While writing on your dashboard, remember to set the article \r\n\t\t\t\tas a public article if you want to make it visible for the rest of the community.</p>\r\n\t\t\t\t<p>Administrator users can access the <a href="#" data-bind="attr: { href: convertRouteToHash(\'admin/panel\') }">admin panel view</a>. If you want to access this view, you\'ll need to have the \r\n\t\t\t\t<span class="label label-info">Administrator</span> role.</p>\r\n\t\t\t\t<p>Try to log in with the following: <span class="label label-success">admin/admin1234</span> and once there, you will be able to check a list with the registered users on this site.</p>\r\n\t\t\t\t<hr />\r\n\t\t\t\t<blockquote class="bs-callout bs-callout-danger">\r\n\t\t\t\t\t<h2>Remember !!</h2>\r\n\t\t\t\t\t<p class="lead">The authorization system in the client can always be hacked! \r\n\t\t\t\t\tAlways authenticate and authorize the request in the server when retrieving the necessary data for your views.</p>\r\n\t\t\t\t</blockquote>\r\n\t\t\t</div>\r\n\t\t</div>\r\n        <div class="row">\r\n\t\t\t<div class="col-lg-12">\r\n\t\t\t\t<div class="page-header">\r\n\t\t\t\t\t<h2>About SEO Optimization</h2>\r\n\t\t\t\t</div>            \r\n                <p>The template is ready to be SEO crawlable. DurandalAuth implements the <a href="#" onclick="window.open(\'https://developers.google.com/webmasters/ajax-crawling/docs/getting-started\', \'_blank\')"> google ajax crawling scheme</a> for pages without hash fragments. You need the default pushstate option enabled.</p>\r\n                <p>I created a interface (Helpers/ISnapshot.cs) that needs to be implemented in order to work.</p>\r\n                <p>The default implementation uses <a href="#" onclick="window.open(\'https://github.com/yagopv/azurecrawler\', \'_blank\')"> a new project I created called AzureCrawler</a>.</p>\r\n                <p>This new project is a Worker Role ready to be deployed to Windows Azure and serving a REST Web API via OWIN. The Web API executes a phantomjs process when receiving requests and returns html snapshots. Moreover, AzureCrawler can save the snapshot to Azure Storage and keep it there with the expiration date you choose, so next time the page is requested for any bot, the stored snapshot will be served.</p>\r\n                <p>I created AzureCrawler like a separate project but it´s easy to bring all the concepts from AzureCrawler to your own project if you want to keep it in the same solution. Another option is creating your own implementation of ISnapshot.cs</p>\r\n\t\t\t</div>\r\n        </div>\r\n\t\t<hr />\r\n\t</div>\r\n</div>';});

define('text!views/notfound.html',[],function () { return '<div id="notfound">\n    <div class="container">\n        <div class="page-header">\n            <h1>Oooooops!!   <small>couldn´t find what you are looking for</small></h1>\n        </div>\n        <h3>There isn´t any page on this site with the url you provided, perhaps you are trying to get the ...</h3>\n        <ul class="list-unstyled mart2">\n            <li><a href="#" data-bind="attr: { href: convertRouteToHash(\'/\') }" class="lead">The home page</a></li>\n            <li><a href="#" data-bind="attr: { href: convertRouteToHash(\'/home/articles\') }" class="lead">Articles in this site</a></li>\n            <li><a href="#" data-bind="attr: { href: convertRouteToHash(\'/user/dashboard\') }" class="lead">Your dashboard</a></li>\n            <li><a href="#" data-bind="attr: { href: convertRouteToHash(\'/account/manage\') }" class="lead">Managing your account</a></li>\n        </ul>        \n    </div>\n</div>';});

define('text!views/shell.html',[],function () { return '<div>\r\n    <header data-bind="compose : \'viewmodels/header\'"></header>\r\n    <div class="page-host" data-bind="router: { transition:\'entrance\', cacheViews:true }"></div>\r\n</div>\r\n\r\n<div class="st-sticky-push"></div>';});

define('text!views/user/article.html',[],function () { return '<div id="#article">\r\n    <div class="container" data-bind="with: article">\r\n        <div class="row">\r\n            <div class="hidden-xs col-sm-3 col-md-2 col-lg-2">\r\n                <div class="st-image">\r\n                    <div class="st-image-container">\r\n                        <a href="#" class="thumbnail">\r\n                            <img data-bind="attr: { src: imageUrl }" />\r\n                        </a>                        \r\n                    </div>\r\n                </div>\r\n            </div>\r\n            <div class="col-xs-12 col-sm-9 col-md-10 col-lg-10">\r\n                <div class="page-header">\r\n                    <h1 class="mart0" data-bind="text: title"></h1>       \r\n                </div>                \r\n                <span class="label label-info" data-bind="text: formattedCreatedDate"></span>\r\n                <span class="label label-info" data-bind="text: createdBy"></span>\r\n            </div>            \r\n        </div>\r\n\r\n        <div class="row col-sm-12 mart2" data-bind="foreach: tags">\r\n            <span class="label label-primary" data-bind="text: name"></span>\r\n        </div>\r\n\r\n        <div class="row col-sm-12">\r\n            <p class="mart2 prewrap lead" data-bind="text: description"></p>\r\n        </div>\r\n\r\n        <div class="row col-sm-12 mart2 prewrap" data-bind="html: html"></div>\r\n\r\n    </div>\r\n</div>\r\n';});

define('text!views/user/dashboard.html',[],function () { return '<div id="dashboard">\r\n    <div class="container">\r\n        <div class="page-header">\r\n            <h1>Dashboard</h1>\r\n        </div>\r\n        <p class="lead">Write, update and delete your personal articles</p>\r\n\r\n        <a href="#" class="btn btn-primary" data-bind="click : newArticle"><i class="icon-plus-sign"></i>   New Article</a>\r\n\r\n        <a href="#" class="btn btn-success" data-bind="click: saveArticles"><i class="icon-save"></i>   Save all changes</a>\r\n\r\n        <!-- Articles List -->\r\n\r\n        <div id="dashboard-articles" data-bind="foreach : { data : articles, afterAdd : utils.addItemAnimation, beforeRemove : utils.removeItemAnimation }" class="mart5">\r\n            <div class="row">\r\n                <div class="hidden-xs col-sm-3 col-md-2 col-lg-2">\r\n                    <div class="st-image">\r\n                        <div class="st-image-container">\r\n                            <a class="thumbnail">\r\n                                <img data-bind="attr: { src: imageUrl }" alt="Article Logo"/>\r\n                            </a>                            \r\n                        </div>\r\n                    </div>                    \r\n                </div>\r\n                <div class="col-xs-12 col-sm-9 col-md-10 col-lg-10">\r\n                    <h2 class="mart0" data-bind="text : title"></h2>\r\n                    <div class="mart2">\r\n                        <span class="label label-info" data-bind="text: formattedCreatedDate"></span>\r\n                        <span class="label label-success" data-bind="visible: isPublished">Published</span>\r\n                        <span class="label label-warning" data-bind="visible: !isPublished()">Pending</span>\r\n                        <span class="label label-danger" data-bind="visible: unsavedChanges">Unsaved changes</span>\r\n                        <span class="label label-danger" data-bind="visible: hasValidationErrors">Article with validation errors</span>\r\n                    </div>\r\n                    <p  class="mart2" data-bind="text : description"></p>\r\n                    <div data-bind="foreach: tags" class="mart2">\r\n                        <span class="label label-primary" data-bind="text: name"></span>\r\n                    </div>\r\n                    <div class="mart2">\r\n                        <a href="#" class="btn btn-primary" data-bind="click: function () { $parent.editArticle(this, $parent) }">Edit</a>\r\n                        <a href="#" class="btn btn-danger" data-bind="click: function () { $parent.deleteArticle(this, $parent, false) }">Delete</a>\r\n                    </div>\r\n                </div>\r\n            </div>\r\n            <hr />\r\n        </div>\r\n\r\n        <!-- Articles List End -->\r\n\r\n        <!-- Edited Article -->\r\n\r\n        <div class="modal fade" id="edited-article"  data-bind="with: selectedArticle">\r\n          <div class="modal-dialog">\r\n                <div class="modal-content">\r\n                    <div class="modal-header">\r\n                        <button type="button" class="close" data-dismiss="modal" aria-hidden="true" data-bind="click: $parent.closeModal">&times;</button>\r\n                        <h1 class="modal-title" data-bind="text: title() == \'\' ? \'New article\' : title"></h1>\r\n                    </div>\r\n                    <div class="modal-body">\r\n                        <div class="form-group" data-bind="validationElement: imageUrl">\r\n                            <div class="page-header">\r\n                                <h2><i class="icon-picture"></i>   Logo  <small>enter logo for the article</small></h2>                                        \r\n                            </div>\r\n                            <div class="row">\r\n                                <div class="col-xs-3 col-sm-4 col-md-3 col-lg-2">\r\n                                    <div class="st-image">\r\n                                        <div class="st-image-container">\r\n                                            <a href="#" class="thumbnail">\r\n                                                <img id="selected-article-img" data-bind="attr: { src: imageUrl }" alt="Url for the image representing the Article" />                                \r\n                                            </a>\r\n                                        </div>\r\n                                    </div>\r\n                                </div>\r\n                                <div class="col-xs-9 col-sm-8 col-md-9 col-lg-10">                                    \r\n                                    <input class="form-control mart2" type="text"  data-bind="value: imageUrl" placeholder="Url for the image representing the Article">                        \r\n                                    <span class="help-block">Enter the image url you would like to use as the main image for this article</span>\r\n                                </div>                                                        \r\n                            </div>\r\n                        </div>\r\n                        <div class="page-header">\r\n                            <h2><i class="icon-list-ul"></i>   Main info   <small>enter some info about the article</small></h2>\r\n                        </div>\r\n                        <div class="form-group" data-bind="validationElement: title">\r\n                             <label class="control-label" for="username">Title</label>                        \r\n                             <input class="form-control" type="text"  data-bind="value: title" placeholder="Title">      \r\n                        </div>\r\n                        <div class="form-group" data-bind="validationElement: description">\r\n                             <label class="control-label" for="username">Brief description</label>                     \r\n                             <textarea rows="4" cols="60" class="form-control" data-bind="value: description" placeholder="Description"></textarea> \r\n                        </div>\r\n                        <div class="form-group" data-bind="validationElement: categoryId">\r\n                            <label class="control-label" for="email">Categorize the article</label>\r\n                            &nbsp;&nbsp;<select data-bind="options: $parent.categories, optionsText: \'name\', optionsValue: \'categoryId\', value: categoryId, optionsCaption: \'Choose...\'"></select>\r\n                        </div>\r\n                        <div class="checkbox">\r\n                            <label>\r\n                                <input type="checkbox" data-bind="checked: isPublished"> <span>Publish</span>\r\n                            </label>\r\n                        </div>\r\n                        <div class="page-header">\r\n                            <h2><i class="icon-pencil"></i>   Content   <small>write your article. Markdown is allowed</small></h2>\r\n                        </div>\r\n                        <div class="form-group" data-bind="validationElement: markdown">\r\n                            <div>\r\n                                <a href="#" class="btn btn-primary"  data-bind="click: function () { $parent.changePreview(this, $parent) }"><i class="icon-eye-open"></i>  Change Edit/Preview</a>\r\n                                <a href="#" class="btn btn-primary go-zen"><i class="icon-pencil"></i>  Edit in Zen Mode with no distraction</a>\r\n                            </div>                        \r\n                            <div class="form-group mart2">                                \r\n                                <textarea rows="10" cols="60" class="form-control auto-height-textarea zen-mode" data-bind="value: markdown, visible: !$parent.preview(), event: { \'change\': $parent.convertMarkdown }" placeholder="Enter content here using markdown"></textarea>\r\n                            </div>\r\n                            <div class="mart5" data-bind="html: html, visible: $parent.preview"></div>\r\n                            <p class="text-right"><abbr title="Markdown is allowed within the textarea. Click preview for watch html result">markdown</abbr></p>\r\n                        </div>\r\n                        <div class="page-header">\r\n                            <h2><i class="icon-tags"></i>   Tags   <small>start tagging your article</small></h2>\r\n                        </div>\r\n                        <div class="form-group">\r\n                             <input id="tags" class="form-control" type="text"  data-bind="value: splitTags">      \r\n                        </div>\r\n                    </div>\r\n                    <div class="modal-footer">\r\n                        <button type="button" class="btn btn-default" data-dismiss="modal" data-bind="click: $parent.closeModal">Close</button>                        \r\n                    </div>\r\n                </div>\r\n            </div>\r\n        </div>\r\n\r\n        <!-- End Edited Article -->\r\n\r\n    </div>\r\n</div>\r\n';});

define('plugins/dialog',["durandal/system","durandal/app","durandal/composition","durandal/activator","durandal/viewEngine","jquery","knockout"],function(e,t,n,r,i,a,o){function s(t){return e.defer(function(n){e.isString(t)?e.acquire(t).then(function(t){n.resolve(e.resolveObject(t))}).fail(function(n){e.error("Failed to load dialog module ("+t+"). Details: "+n.message)}):n.resolve(t)}).promise()}var l,c={},u=0,d=function(e,t,n){this.message=e,this.title=t||d.defaultTitle,this.options=n||d.defaultOptions};return d.prototype.selectOption=function(e){l.close(this,e)},d.prototype.getView=function(){return i.processMarkup(d.defaultViewMarkup)},d.setViewUrl=function(e){delete d.prototype.getView,d.prototype.viewUrl=e},d.defaultTitle=t.title||"Application",d.defaultOptions=["Ok"],d.defaultViewMarkup=['<div data-view="plugins/messageBox" class="messageBox">','<div class="modal-header">','<h3 data-bind="text: title"></h3>',"</div>",'<div class="modal-body">','<p class="message" data-bind="text: message"></p>',"</div>",'<div class="modal-footer" data-bind="foreach: options">','<button class="btn" data-bind="click: function () { $parent.selectOption($data); }, text: $data, css: { \'btn-primary\': $index() == 0, autofocus: $index() == 0 }"></button>',"</div>","</div>"].join("\n"),l={MessageBox:d,currentZIndex:1050,getNextZIndex:function(){return++this.currentZIndex},isOpen:function(){return u>0},getContext:function(e){return c[e||"default"]},addContext:function(e,t){t.name=e,c[e]=t;var n="show"+e.substr(0,1).toUpperCase()+e.substr(1);this[n]=function(t,n){return this.show(t,n,e)}},createCompositionSettings:function(e,t){var n={model:e,activate:!1};return t.attached&&(n.attached=t.attached),t.compositionComplete&&(n.compositionComplete=t.compositionComplete),n},getDialog:function(e){return e?e.__dialog__:void 0},close:function(e){var t=this.getDialog(e);if(t){var n=Array.prototype.slice.call(arguments,1);t.close.apply(t,n)}},show:function(t,i,a){var o=this,l=c[a||"default"];return e.defer(function(e){s(t).then(function(t){var a=r.create();a.activateItem(t,i).then(function(r){if(r){var i=t.__dialog__={owner:t,context:l,activator:a,close:function(){var n=arguments;a.deactivateItem(t,!0).then(function(r){r&&(u--,l.removeHost(i),delete t.__dialog__,0==n.length?e.resolve():1==n.length?e.resolve(n[0]):e.resolve.apply(e,n))})}};i.settings=o.createCompositionSettings(t,l),l.addHost(i),u++,n.compose(i.host,i.settings)}else e.resolve(!1)})})}).promise()},showMessage:function(t,n,r){return e.isString(this.MessageBox)?l.show(this.MessageBox,[t,n||d.defaultTitle,r||d.defaultOptions]):l.show(new this.MessageBox(t,n,r))},install:function(e){t.showDialog=function(e,t,n){return l.show(e,t,n)},t.showMessage=function(e,t,n){return l.showMessage(e,t,n)},e.messageBox&&(l.MessageBox=e.messageBox),e.messageBoxView&&(l.MessageBox.prototype.getView=function(){return e.messageBoxView})}},l.addContext("default",{blockoutOpacity:.2,removeDelay:200,addHost:function(e){var t=a("body"),n=a('<div class="modalBlockout"></div>').css({"z-index":l.getNextZIndex(),opacity:this.blockoutOpacity}).appendTo(t),r=a('<div class="modalHost"></div>').css({"z-index":l.getNextZIndex()}).appendTo(t);if(e.host=r.get(0),e.blockout=n.get(0),!l.isOpen()){e.oldBodyMarginRight=t.css("margin-right"),e.oldInlineMarginRight=t.get(0).style.marginRight;var i=a("html"),o=t.outerWidth(!0),s=i.scrollTop();a("html").css("overflow-y","hidden");var c=a("body").outerWidth(!0);t.css("margin-right",c-o+parseInt(e.oldBodyMarginRight)+"px"),i.scrollTop(s)}},removeHost:function(e){if(a(e.host).css("opacity",0),a(e.blockout).css("opacity",0),setTimeout(function(){o.removeNode(e.host),o.removeNode(e.blockout)},this.removeDelay),!l.isOpen()){var t=a("html"),n=t.scrollTop();t.css("overflow-y","").scrollTop(n),e.oldInlineMarginRight?a("body").css("margin-right",e.oldBodyMarginRight):a("body").css("margin-right","")}},compositionComplete:function(e,t,n){var r=a(e),i=r.width(),o=r.height(),s=l.getDialog(n.model);r.css({"margin-top":(-o/2).toString()+"px","margin-left":(-i/2).toString()+"px"}),a(s.host).css("opacity",1),a(e).hasClass("autoclose")&&a(s.blockout).click(function(){s.close()}),a(".autofocus",e).each(function(){a(this).focus()})}}),l});
define('plugins/http',["jquery","knockout"],function(e,t){return{callbackParam:"callback",get:function(t,n){return e.ajax(t,{data:n})},jsonp:function(t,n,r){return-1==t.indexOf("=?")&&(r=r||this.callbackParam,t+=-1==t.indexOf("?")?"?":"&",t+=r+"=?"),e.ajax({url:t,dataType:"jsonp",data:n})},post:function(n,r){return e.ajax({url:n,data:t.toJSON(r),type:"POST",contentType:"application/json",dataType:"json"})}}});
define('plugins/observable',["durandal/system","durandal/binder","knockout"],function(e,t,n){function r(e){var t=e[0];return"_"===t||"$"===t}function a(t){if(!t||e.isElement(t)||t.ko===n||t.jquery)return!1;var r=d.call(t);return-1==v.indexOf(r)&&!(t===!0||t===!1)}function i(e,t){var n=e.__observable__,r=!0;if(!n||!n.__full__){n=n||(e.__observable__={}),n.__full__=!0,f.forEach(function(n){e[n]=function(){r=!1;var e=m[n].apply(t,arguments);return r=!0,e}}),h.forEach(function(n){e[n]=function(){r&&t.valueWillMutate();var a=p[n].apply(e,arguments);return r&&t.valueHasMutated(),a}}),g.forEach(function(n){e[n]=function(){for(var a=0,i=arguments.length;i>a;a++)o(arguments[a]);r&&t.valueWillMutate();var s=p[n].apply(e,arguments);return r&&t.valueHasMutated(),s}}),e.splice=function(){for(var n=2,a=arguments.length;a>n;n++)o(arguments[n]);r&&t.valueWillMutate();var i=p.splice.apply(e,arguments);return r&&t.valueHasMutated(),i};for(var a=0,i=e.length;i>a;a++)o(e[a])}}function o(t){var o,s;if(a(t)&&(o=t.__observable__,!o||!o.__full__)){if(o=o||(t.__observable__={}),o.__full__=!0,e.isArray(t)){var c=n.observableArray(t);i(t,c)}else for(var u in t)r(u)||o[u]||(s=t[u],e.isFunction(s)||l(t,u,s));b&&e.log("Converted",t)}}function s(e,t,n){var r;e(t),r=e.peek(),n?r.destroyAll||(r||(r=[],e(r)),i(r,e)):o(r)}function l(t,r,a){var l,c,u=t.__observable__||(t.__observable__={});if(void 0===a&&(a=t[r]),e.isArray(a))l=n.observableArray(a),i(a,l),c=!0;else if("function"==typeof a){if(!n.isObservable(a))return null;l=a}else e.isPromise(a)?(l=n.observable(),a.then(function(t){if(e.isArray(t)){var r=n.observableArray(t);i(t,r),t=r}l(t)})):(l=n.observable(a),o(a));return Object.defineProperty(t,r,{configurable:!0,enumerable:!0,get:l,set:n.isWriteableObservable(l)?function(t){t&&e.isPromise(t)?t.then(function(t){s(l,t,e.isArray(t))}):s(l,t,c)}:void 0}),u[r]=l,l}function c(t,n,r){var a,i=this,o={owner:t,deferEvaluation:!0};return"function"==typeof r?o.read=r:("value"in r&&e.error('For ko.defineProperty, you must not specify a "value" for the property. You must provide a "get" function.'),"function"!=typeof r.get&&e.error('For ko.defineProperty, the third parameter must be either an evaluator function, or an options object containing a function called "get".'),o.read=r.get,o.write=r.set),a=i.computed(o),t[n]=a,l(t,n,a)}var u,d=Object.prototype.toString,v=["[object Function]","[object String]","[object Boolean]","[object Number]","[object Date]","[object RegExp]"],f=["remove","removeAll","destroy","destroyAll","replace"],h=["pop","reverse","sort","shift","splice"],g=["push","unshift"],p=Array.prototype,m=n.observableArray.fn,b=!1;return u=function(e,t){var r,a,i;return e?(r=e.__observable__,r&&(a=r[t])?a:(i=e[t],n.isObservable(i)?i:l(e,t,i))):null},u.defineProperty=c,u.convertProperty=l,u.convertObject=o,u.install=function(e){var n=t.binding;t.binding=function(e,t,r){r.applyBindings&&!r.skipConversion&&o(e),n(e,t)},b=e.logConversion},u});
define('plugins/serializer',["durandal/system"],function(e){return{typeAttribute:"type",space:void 0,replacer:function(e,t){if(e){var n=e[0];if("_"===n||"$"===n)return void 0}return t},serialize:function(t,n){return n=void 0===n?{}:n,(e.isString(n)||e.isNumber(n))&&(n={space:n}),JSON.stringify(t,n.replacer||this.replacer,n.space||this.space)},getTypeId:function(e){return e?e[this.typeAttribute]:void 0},typeMap:{},registerType:function(){var t=arguments[0];if(1==arguments.length){var n=t[this.typeAttribute]||e.getModuleId(t);this.typeMap[n]=t}else this.typeMap[t]=arguments[1]},reviver:function(e,t,n,r){var a=n(t);if(a){var i=r(a);if(i)return i.fromJSON?i.fromJSON(t):new i(t)}return t},deserialize:function(e,t){var n=this;t=t||{};var r=t.getTypeId||function(e){return n.getTypeId(e)},a=t.getConstructor||function(e){return n.typeMap[e]},i=t.reviver||function(e,t){return n.reviver(e,t,r,a)};return JSON.parse(e,i)}}});
define('plugins/widget',["durandal/system","durandal/composition","jquery","knockout"],function(e,t,n,r){function a(e,n){var a=r.utils.domData.get(e,c);a||(a={parts:t.cloneNodes(r.virtualElements.childNodes(e))},r.virtualElements.emptyNode(e),r.utils.domData.set(e,c,a)),n.parts=a.parts}var i={},o={},s=["model","view","kind"],c="durandal-widget-data",l={getSettings:function(t){var n=r.utils.unwrapObservable(t())||{};if(e.isString(n))return{kind:n};for(var a in n)n[a]=-1!=r.utils.arrayIndexOf(s,a)?r.utils.unwrapObservable(n[a]):n[a];return n},registerKind:function(e){r.bindingHandlers[e]={init:function(){return{controlsDescendantBindings:!0}},update:function(t,n,r,i,o){var s=l.getSettings(n);s.kind=e,a(t,s),l.create(t,s,o,!0)}},r.virtualElements.allowedBindings[e]=!0},mapKind:function(e,t,n){t&&(o[e]=t),n&&(i[e]=n)},mapKindToModuleId:function(e){return i[e]||l.convertKindToModulePath(e)},convertKindToModulePath:function(e){return"widgets/"+e+"/viewmodel"},mapKindToViewId:function(e){return o[e]||l.convertKindToViewPath(e)},convertKindToViewPath:function(e){return"widgets/"+e+"/view"},createCompositionSettings:function(e,t){return t.model||(t.model=this.mapKindToModuleId(t.kind)),t.view||(t.view=this.mapKindToViewId(t.kind)),t.preserveContext=!0,t.activate=!0,t.activationData=t,t.mode="templated",t},create:function(e,n,r,a){a||(n=l.getSettings(function(){return n},e));var i=l.createCompositionSettings(e,n);t.compose(e,i,r)},install:function(e){if(e.bindingName=e.bindingName||"widget",e.kinds)for(var t=e.kinds,n=0;n<t.length;n++)l.registerKind(t[n]);r.bindingHandlers[e.bindingName]={init:function(){return{controlsDescendantBindings:!0}},update:function(e,t,n,r,i){var o=l.getSettings(t);a(e,o),l.create(e,o,i,!0)}},r.virtualElements.allowedBindings[e.bindingName]=!0}};return l});
define('transitions/entrance',["durandal/system","durandal/composition","jquery"],function(e,t,n){var r=100,i={marginRight:0,marginLeft:0,opacity:1},a={marginLeft:"",marginRight:"",opacity:"",display:""},o=function(t){return e.defer(function(e){function o(){e.resolve()}function s(){t.keepScrollPosition||n(document).scrollTop(0)}function c(){s(),t.triggerAttach();var e={marginLeft:u?"0":"20px",marginRight:u?"0":"-20px",opacity:0,display:"block"},r=n(t.child);r.css(e),r.animate(i,l,"swing",function(){r.css(a),o()})}if(t.child){var l=t.duration||500,u=!!t.fadeOnly;t.activeView?n(t.activeView).fadeOut(r,c):c()}else n(t.activeView).fadeOut(r,o)}).promise()};return o});
require(["main"]);
}());